/******************************************************************
   IP*Works! SSL V9 C++ Edition
   Copyright (c) 2013 /n software inc. - All rights reserved.
*******************************************************************/

#ifndef _IPWORKSSSL_CALDAVS_H_
#define _IPWORKSSSL_CALDAVS_H_

#define IPWORKSSSL_ONLY_TYPES
#include "ipworksssl.h"
#include "ipworksssl.key"

//Actions
#define A_NO_ALARM                                         0
#define A_AUDIO                                            1
#define A_DISPLAY                                          2
#define A_EMAIL                                            3

//AuthSchemes
#define AUTH_BASIC                                         0
#define AUTH_DIGEST                                        1
#define AUTH_PROPRIETARY                                   2
#define AUTH_NONE                                          3
#define AUTH_NTLM                                          4
#define AUTH_NEGOTIATE                                     5
#define AUTH_OAUTH                                         6

//TDepth
#define DP_UNSPECIFIED                                     0
#define DP_RESOURCE_ONLY                                   1
#define DP_IMMEDIATE_CHILDREN                              2
#define DP_INFINITY                                        3

//EventTypes
#define V_EVENT                                            0
#define V_TODO                                             1
#define V_JOURNAL                                          2
#define V_FREE_BUSY                                        3

//FirewallTypes
#define FW_NONE                                            0
#define FW_TUNNEL                                          1
#define FW_SOCKS4                                          2
#define FW_SOCKS5                                          3

//TFollowRedirects
#define FR_NEVER                                           0
#define FR_ALWAYS                                          1
#define FR_SAME_SCHEME                                     2

//ProxySSLTypes
#define PS_AUTOMATIC                                       0
#define PS_ALWAYS                                          1
#define PS_NEVER                                           2
#define PS_TUNNEL                                          3

//VEventTypes
#define VT_EVENT                                           0
#define VT_TODO                                            1
#define VT_JOURNAL                                         2
#define VT_FREE_BUSY                                       3
#define VT_ALL                                             4

//CertStoreTypes
#define CST_USER                                           0
#define CST_MACHINE                                        1
#define CST_PFXFILE                                        2
#define CST_PFXBLOB                                        3
#define CST_JKSFILE                                        4
#define CST_JKSBLOB                                        5
#define CST_PEMKEY_FILE                                    6
#define CST_PEMKEY_BLOB                                    7
#define CST_PUBLIC_KEY_FILE                                8
#define CST_PUBLIC_KEY_BLOB                                9
#define CST_SSHPUBLIC_KEY_BLOB                             10
#define CST_P7BFILE                                        11
#define CST_P7BBLOB                                        12
#define CST_SSHPUBLIC_KEY_FILE                             13


extern "C" void* IPWORKSSSL_CALL IPWorksSSL_CalDAVS_Create(PIPWORKSSSL_CALLBACK lpSink, void *lpContext, char *lpOemKey);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_CalDAVS_Destroy(void *lpObj);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_CalDAVS_CheckIndex(void *lpObj, int propid, int arridx);
extern "C" void* IPWORKSSSL_CALL IPWorksSSL_CalDAVS_Get(void *lpObj, int propid, int arridx, int *lpcbVal);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_CalDAVS_Set(void *lpObj, int propid, int arridx, const void *val, int cbVal);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_CalDAVS_Do(void *lpObj, int methid, int cparam, void *param[], int cbparam[]);
extern "C" char* IPWORKSSSL_CALL IPWorksSSL_CalDAVS_GetLastError(void *lpObj);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_CalDAVS_GetLastErrorCode(void *lpObj);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_CalDAVS_StaticInit(void *hInst);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_CalDAVS_StaticDestroy();

#ifdef WIN32
#include <windows.h>
#pragma warning(disable:4311) 
#pragma warning(disable:4312) 
#endif

typedef struct {
  int StatusCode;
  const char* Description;
  int reserved;
} CalDAVSConnectedEventParams;

typedef struct {
  const char* ConnectionEvent;
  int StatusCode;
  const char* Description;
  int reserved;
} CalDAVSConnectionStatusEventParams;

typedef struct {
  int StatusCode;
  const char* Description;
  int reserved;
} CalDAVSDisconnectedEventParams;

typedef struct {
  int Direction;
  int reserved;
} CalDAVSEndTransferEventParams;

typedef struct {
  int ErrorCode;
  const char* Description;
  int reserved;
} CalDAVSErrorEventParams;

typedef struct {
  const char* ResourceURI;
  const char* ResponseStatus;
  const char* ETag;
  const char* CalendarData;
  int reserved;
} CalDAVSEventDetailsEventParams;

typedef struct {
  const char* BusyType;
  const char* BusyRange;
  int reserved;
} CalDAVSFreeBusyEventParams;

typedef struct {
  const char* Field;
  const char* Value;
  int reserved;
} CalDAVSHeaderEventParams;

typedef struct {
  const char* Location;
  int Accept;
  int reserved;
} CalDAVSRedirectEventParams;

typedef struct {
  const char* Name;
  const char* Value;
  const char* Expires;
  const char* Domain;
  const char* Path;
  int Secure;
  int reserved;
} CalDAVSSetCookieEventParams;

typedef struct {
  const char* CertEncoded;
  const char* CertSubject;
  const char* CertIssuer;
  const char* Status;
  int Accept;
  int lenCertEncoded;
  int reserved;
} CalDAVSSSLServerAuthenticationEventParams;

typedef struct {
  const char* Message;
  int reserved;
} CalDAVSSSLStatusEventParams;

typedef struct {
  int Direction;
  int reserved;
} CalDAVSStartTransferEventParams;

typedef struct {
  const char* HTTPVersion;
  int StatusCode;
  const char* Description;
  int reserved;
} CalDAVSStatusEventParams;

typedef struct {
  int Direction;
  ns_int64 *pBytesTransferred;
  int PercentDone;
  const char* Text;
  int lenText;
  int reserved;
} CalDAVSTransferEventParams;



class CalDAVS {
  
  public: //events
  
    virtual int FireConnected(CalDAVSConnectedEventParams *e) {return 0;}
    virtual int FireConnectionStatus(CalDAVSConnectionStatusEventParams *e) {return 0;}
    virtual int FireDisconnected(CalDAVSDisconnectedEventParams *e) {return 0;}
    virtual int FireEndTransfer(CalDAVSEndTransferEventParams *e) {return 0;}
    virtual int FireError(CalDAVSErrorEventParams *e) {return 0;}
    virtual int FireEventDetails(CalDAVSEventDetailsEventParams *e) {return 0;}
    virtual int FireFreeBusy(CalDAVSFreeBusyEventParams *e) {return 0;}
    virtual int FireHeader(CalDAVSHeaderEventParams *e) {return 0;}
    virtual int FireRedirect(CalDAVSRedirectEventParams *e) {return 0;}
    virtual int FireSetCookie(CalDAVSSetCookieEventParams *e) {return 0;}
    virtual int FireSSLServerAuthentication(CalDAVSSSLServerAuthenticationEventParams *e) {return 0;}
    virtual int FireSSLStatus(CalDAVSSSLStatusEventParams *e) {return 0;}
    virtual int FireStartTransfer(CalDAVSStartTransferEventParams *e) {return 0;}
    virtual int FireStatus(CalDAVSStatusEventParams *e) {return 0;}
    virtual int FireTransfer(CalDAVSTransferEventParams *e) {return 0;}


  protected:

    void *m_pObj;
    
    static int IPWORKSSSL_CALL CalDAVSEventSink(void *lpObj, int event_id, int cparam, void *param[], int cbparam[]) {
      int ret_code = 0;
      if (event_id > 10000) return ((CalDAVS*)lpObj)->CalDAVSEventSinkW(event_id - 10000, cparam, param, cbparam);
      switch (event_id) {
         case 1: {
            CalDAVSConnectedEventParams e = {(int)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireConnected(&e);
            break;
         }
         case 2: {
            CalDAVSConnectionStatusEventParams e = {(char*)IPS64CAST(param[0]), (int)IPS64CAST(param[1]), (char*)IPS64CAST(param[2]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireConnectionStatus(&e);
            break;
         }
         case 3: {
            CalDAVSDisconnectedEventParams e = {(int)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireDisconnected(&e);
            break;
         }
         case 4: {
            CalDAVSEndTransferEventParams e = {(int)IPS64CAST(param[0]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireEndTransfer(&e);
            break;
         }
         case 5: {
            CalDAVSErrorEventParams e = {(int)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireError(&e);
            break;
         }
         case 6: {
            CalDAVSEventDetailsEventParams e = {(char*)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]), (char*)IPS64CAST(param[2]), (char*)IPS64CAST(param[3]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireEventDetails(&e);
            break;
         }
         case 7: {
            CalDAVSFreeBusyEventParams e = {(char*)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireFreeBusy(&e);
            break;
         }
         case 8: {
            CalDAVSHeaderEventParams e = {(char*)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireHeader(&e);
            break;
         }
         case 9: {
            CalDAVSRedirectEventParams e = {(char*)IPS64CAST(param[0]), (int)IPS64CAST(param[1]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireRedirect(&e);
            param[1] = (void*)IPS64CAST(e.Accept);
            break;
         }
         case 10: {
            CalDAVSSetCookieEventParams e = {(char*)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]), (char*)IPS64CAST(param[2]), (char*)IPS64CAST(param[3]), (char*)IPS64CAST(param[4]), (int)IPS64CAST(param[5]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireSetCookie(&e);
            break;
         }
         case 11: {
            CalDAVSSSLServerAuthenticationEventParams e = {(char*)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]), (char*)IPS64CAST(param[2]), (char*)IPS64CAST(param[3]), (int)IPS64CAST(param[4]), (int)IPS64CAST(cbparam[0]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireSSLServerAuthentication(&e);
            param[4] = (void*)IPS64CAST(e.Accept);
            break;
         }
         case 12: {
            CalDAVSSSLStatusEventParams e = {(char*)IPS64CAST(param[0]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireSSLStatus(&e);
            break;
         }
         case 13: {
            CalDAVSStartTransferEventParams e = {(int)IPS64CAST(param[0]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireStartTransfer(&e);
            break;
         }
         case 14: {
            CalDAVSStatusEventParams e = {(char*)IPS64CAST(param[0]), (int)IPS64CAST(param[1]), (char*)IPS64CAST(param[2]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireStatus(&e);
            break;
         }
         case 15: {
            CalDAVSTransferEventParams e = {(int)IPS64CAST(param[0]), (ns_int64*)IPS64CAST(param[1]), (int)IPS64CAST(param[2]), (char*)IPS64CAST(param[3]), (int)IPS64CAST(cbparam[3]),  0};
            ret_code = ((CalDAVS*)lpObj)->FireTransfer(&e);
            break;
         }

      }
      return ret_code;
    }

    virtual int CalDAVSEventSinkW(int event_id, int cparam, void *param[], int cbparam[]) {return 0;}

  public:

    CalDAVS(char *lpOemKey = (char*)IPWORKSSSL_OEMKEY_98) {
      m_pObj = IPWorksSSL_CalDAVS_Create(CalDAVSEventSink, (void*)this, (char*)lpOemKey);
    }

    virtual ~CalDAVS() {
      IPWorksSSL_CalDAVS_Destroy(m_pObj);
    }

  public:

    inline char *GetLastError() {
      return IPWorksSSL_CalDAVS_GetLastError(m_pObj);
    }
    
    inline int GetLastErrorCode() {
      return IPWorksSSL_CalDAVS_GetLastErrorCode(m_pObj);
    }

    inline char *VERSION() {
      return (char*)IPWorksSSL_CalDAVS_Get(m_pObj, 0, 0, 0);
    }

  public: //properties

    inline int GetAlarmCount() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 1, 0, 0);
      return (int)(long)val;
    }
    inline int SetAlarmCount(int iAlarmCount) {
      void* val = (void*)IPS64CAST(iAlarmCount);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 1, 0, val, 0);
    }
    inline int GetAlarmAction(int iAlarmIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 2, iAlarmIndex, 0);
      return (int)(long)val;
    }
    inline int SetAlarmAction(int iAlarmIndex, int iAlarmAction) {
      void* val = (void*)IPS64CAST(iAlarmAction);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 2, iAlarmIndex, val, 0);
    }
    inline char* GetAlarmAttachment(int iAlarmIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 3, iAlarmIndex, 0);
      return (char*)val;
    }

    inline int SetAlarmAttachment(int iAlarmIndex, const char *lpAlarmAttachment) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 3, iAlarmIndex, (void*)lpAlarmAttachment, 0);
    }

    inline char* GetAlarmAttachmentType(int iAlarmIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 4, iAlarmIndex, 0);
      return (char*)val;
    }

    inline int SetAlarmAttachmentType(int iAlarmIndex, const char *lpAlarmAttachmentType) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 4, iAlarmIndex, (void*)lpAlarmAttachmentType, 0);
    }

    inline char* GetAlarmDuration(int iAlarmIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 5, iAlarmIndex, 0);
      return (char*)val;
    }

    inline int SetAlarmDuration(int iAlarmIndex, const char *lpAlarmDuration) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 5, iAlarmIndex, (void*)lpAlarmDuration, 0);
    }

    inline char* GetAlarmMessage(int iAlarmIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 6, iAlarmIndex, 0);
      return (char*)val;
    }

    inline int SetAlarmMessage(int iAlarmIndex, const char *lpAlarmMessage) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 6, iAlarmIndex, (void*)lpAlarmMessage, 0);
    }

    inline char* GetAlarmRecipient(int iAlarmIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 7, iAlarmIndex, 0);
      return (char*)val;
    }

    inline int SetAlarmRecipient(int iAlarmIndex, const char *lpAlarmRecipient) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 7, iAlarmIndex, (void*)lpAlarmRecipient, 0);
    }

    inline int GetAlarmRepeat(int iAlarmIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 8, iAlarmIndex, 0);
      return (int)(long)val;
    }
    inline int SetAlarmRepeat(int iAlarmIndex, int iAlarmRepeat) {
      void* val = (void*)IPS64CAST(iAlarmRepeat);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 8, iAlarmIndex, val, 0);
    }
    inline char* GetAlarmSubject(int iAlarmIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 9, iAlarmIndex, 0);
      return (char*)val;
    }

    inline int SetAlarmSubject(int iAlarmIndex, const char *lpAlarmSubject) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 9, iAlarmIndex, (void*)lpAlarmSubject, 0);
    }

    inline char* GetAlarmTrigger(int iAlarmIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 10, iAlarmIndex, 0);
      return (char*)val;
    }

    inline int SetAlarmTrigger(int iAlarmIndex, const char *lpAlarmTrigger) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10, iAlarmIndex, (void*)lpAlarmTrigger, 0);
    }

    inline char* GetAttendees() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 11, 0, 0);
      return (char*)val;
    }

    inline int SetAttendees(const char *lpAttendees) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 11, 0, (void*)lpAttendees, 0);
    }

    inline char* GetAuthorization() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 12, 0, 0);
      return (char*)val;
    }

    inline int SetAuthorization(const char *lpAuthorization) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 12, 0, (void*)lpAuthorization, 0);
    }

    inline int GetAuthScheme() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 13, 0, 0);
      return (int)(long)val;
    }
    inline int SetAuthScheme(int iAuthScheme) {
      void* val = (void*)IPS64CAST(iAuthScheme);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 13, 0, val, 0);
    }
    inline char* GetCategories() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 14, 0, 0);
      return (char*)val;
    }

    inline int SetCategories(const char *lpCategories) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 14, 0, (void*)lpCategories, 0);
    }

    inline char* GetClassification() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 15, 0, 0);
      return (char*)val;
    }

    inline int SetClassification(const char *lpClassification) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 15, 0, (void*)lpClassification, 0);
    }

    inline char* GetCompleted() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 16, 0, 0);
      return (char*)val;
    }

    inline int SetCompleted(const char *lpCompleted) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 16, 0, (void*)lpCompleted, 0);
    }

    inline int GetConnected() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 17, 0, 0);
      return (int)(long)val;
    }
    inline int SetConnected(int bConnected) {
      void* val = (void*)IPS64CAST(bConnected);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 17, 0, val, 0);
    }
    inline int GetCookieCount() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 18, 0, 0);
      return (int)(long)val;
    }
    inline int SetCookieCount(int iCookieCount) {
      void* val = (void*)IPS64CAST(iCookieCount);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 18, 0, val, 0);
    }
    inline char* GetCookieDomain(int iCookieIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 19, iCookieIndex, 0);
      return (char*)val;
    }


    inline char* GetCookieExpiration(int iCookieIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 20, iCookieIndex, 0);
      return (char*)val;
    }


    inline char* GetCookieName(int iCookieIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 21, iCookieIndex, 0);
      return (char*)val;
    }

    inline int SetCookieName(int iCookieIndex, const char *lpCookieName) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 21, iCookieIndex, (void*)lpCookieName, 0);
    }

    inline char* GetCookiePath(int iCookieIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 22, iCookieIndex, 0);
      return (char*)val;
    }


    inline int GetCookieSecure(int iCookieIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 23, iCookieIndex, 0);
      return (int)(long)val;
    }

    inline char* GetCookieValue(int iCookieIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 24, iCookieIndex, 0);
      return (char*)val;
    }

    inline int SetCookieValue(int iCookieIndex, const char *lpCookieValue) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 24, iCookieIndex, (void*)lpCookieValue, 0);
    }

    inline char* GetCreated() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 25, 0, 0);
      return (char*)val;
    }

    inline int SetCreated(const char *lpCreated) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 25, 0, (void*)lpCreated, 0);
    }

    inline int GetCustomPropertyCount() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 26, 0, 0);
      return (int)(long)val;
    }
    inline int SetCustomPropertyCount(int iCustomPropertyCount) {
      void* val = (void*)IPS64CAST(iCustomPropertyCount);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 26, 0, val, 0);
    }
    inline char* GetCustomPropertyAttribute(int iCustomPropertyIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 27, iCustomPropertyIndex, 0);
      return (char*)val;
    }

    inline int SetCustomPropertyAttribute(int iCustomPropertyIndex, const char *lpCustomPropertyAttribute) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 27, iCustomPropertyIndex, (void*)lpCustomPropertyAttribute, 0);
    }

    inline char* GetCustomPropertyName(int iCustomPropertyIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 28, iCustomPropertyIndex, 0);
      return (char*)val;
    }

    inline int SetCustomPropertyName(int iCustomPropertyIndex, const char *lpCustomPropertyName) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 28, iCustomPropertyIndex, (void*)lpCustomPropertyName, 0);
    }

    inline char* GetCustomPropertyValue(int iCustomPropertyIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 29, iCustomPropertyIndex, 0);
      return (char*)val;
    }

    inline int SetCustomPropertyValue(int iCustomPropertyIndex, const char *lpCustomPropertyValue) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 29, iCustomPropertyIndex, (void*)lpCustomPropertyValue, 0);
    }

    inline int GetDepth() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 30, 0, 0);
      return (int)(long)val;
    }
    inline int SetDepth(int iDepth) {
      void* val = (void*)IPS64CAST(iDepth);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 30, 0, val, 0);
    }
    inline char* GetDescription() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 31, 0, 0);
      return (char*)val;
    }

    inline int SetDescription(const char *lpDescription) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 31, 0, (void*)lpDescription, 0);
    }

    inline char* GetDisplayName() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 32, 0, 0);
      return (char*)val;
    }

    inline int SetDisplayName(const char *lpDisplayName) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 32, 0, (void*)lpDisplayName, 0);
    }

    inline char* GetDuration() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 33, 0, 0);
      return (char*)val;
    }

    inline int SetDuration(const char *lpDuration) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 33, 0, (void*)lpDuration, 0);
    }

    inline char* GetEndDate() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 34, 0, 0);
      return (char*)val;
    }

    inline int SetEndDate(const char *lpEndDate) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 34, 0, (void*)lpEndDate, 0);
    }

    inline char* GetETag() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 35, 0, 0);
      return (char*)val;
    }

    inline int SetETag(const char *lpETag) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 35, 0, (void*)lpETag, 0);
    }

    inline int GetEventType() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 36, 0, 0);
      return (int)(long)val;
    }
    inline int SetEventType(int iEventType) {
      void* val = (void*)IPS64CAST(iEventType);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 36, 0, val, 0);
    }
    inline int GetFirewallAutoDetect() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 37, 0, 0);
      return (int)(long)val;
    }
    inline int SetFirewallAutoDetect(int bFirewallAutoDetect) {
      void* val = (void*)IPS64CAST(bFirewallAutoDetect);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 37, 0, val, 0);
    }
    inline int GetFirewallType() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 38, 0, 0);
      return (int)(long)val;
    }
    inline int SetFirewallType(int iFirewallType) {
      void* val = (void*)IPS64CAST(iFirewallType);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 38, 0, val, 0);
    }
    inline char* GetFirewallHost() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 39, 0, 0);
      return (char*)val;
    }

    inline int SetFirewallHost(const char *lpFirewallHost) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 39, 0, (void*)lpFirewallHost, 0);
    }

    inline char* GetFirewallPassword() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 40, 0, 0);
      return (char*)val;
    }

    inline int SetFirewallPassword(const char *lpFirewallPassword) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 40, 0, (void*)lpFirewallPassword, 0);
    }

    inline int GetFirewallPort() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 41, 0, 0);
      return (int)(long)val;
    }
    inline int SetFirewallPort(int lFirewallPort) {
      void* val = (void*)IPS64CAST(lFirewallPort);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 41, 0, val, 0);
    }
    inline char* GetFirewallUser() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 42, 0, 0);
      return (char*)val;
    }

    inline int SetFirewallUser(const char *lpFirewallUser) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 42, 0, (void*)lpFirewallUser, 0);
    }

    inline int GetFollowRedirects() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 43, 0, 0);
      return (int)(long)val;
    }
    inline int SetFollowRedirects(int iFollowRedirects) {
      void* val = (void*)IPS64CAST(iFollowRedirects);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 43, 0, val, 0);
    }
    inline int GetFreeBusyCount() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 44, 0, 0);
      return (int)(long)val;
    }

    inline char* GetFreeBusyRange(int iFreeBusyIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 45, iFreeBusyIndex, 0);
      return (char*)val;
    }


    inline char* GetFreeBusyType(int iFreeBusyIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 46, iFreeBusyIndex, 0);
      return (char*)val;
    }


    inline int GetIdle() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 47, 0, 0);
      return (int)(long)val;
    }

    inline char* GetLastModified() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 48, 0, 0);
      return (char*)val;
    }

    inline int SetLastModified(const char *lpLastModified) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 48, 0, (void*)lpLastModified, 0);
    }

    inline char* GetLocalHost() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 49, 0, 0);
      return (char*)val;
    }

    inline int SetLocalHost(const char *lpLocalHost) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 49, 0, (void*)lpLocalHost, 0);
    }

    inline char* GetLocation() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 50, 0, 0);
      return (char*)val;
    }

    inline int SetLocation(const char *lpLocation) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 50, 0, (void*)lpLocation, 0);
    }

    inline char* GetLockType() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 51, 0, 0);
      return (char*)val;
    }

    inline int SetLockType(const char *lpLockType) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 51, 0, (void*)lpLockType, 0);
    }

    inline char* GetLockOwner() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 52, 0, 0);
      return (char*)val;
    }

    inline int SetLockOwner(const char *lpLockOwner) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 52, 0, (void*)lpLockOwner, 0);
    }

    inline char* GetLockScope() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 53, 0, 0);
      return (char*)val;
    }

    inline int SetLockScope(const char *lpLockScope) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 53, 0, (void*)lpLockScope, 0);
    }

    inline int GetLockTimeout() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 54, 0, 0);
      return (int)(long)val;
    }
    inline int SetLockTimeout(int iLockTimeout) {
      void* val = (void*)IPS64CAST(iLockTimeout);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 54, 0, val, 0);
    }
    inline char* GetLockTokens() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 55, 0, 0);
      return (char*)val;
    }

    inline int SetLockTokens(const char *lpLockTokens) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 55, 0, (void*)lpLockTokens, 0);
    }

    inline char* GetOrganizer() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 56, 0, 0);
      return (char*)val;
    }

    inline int SetOrganizer(const char *lpOrganizer) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 56, 0, (void*)lpOrganizer, 0);
    }

    inline char* GetOtherHeaders() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 57, 0, 0);
      return (char*)val;
    }

    inline int SetOtherHeaders(const char *lpOtherHeaders) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 57, 0, (void*)lpOtherHeaders, 0);
    }

    inline int GetParsedHeaderCount() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 58, 0, 0);
      return (int)(long)val;
    }

    inline char* GetParsedHeaderField(int iParsedHeaderIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 59, iParsedHeaderIndex, 0);
      return (char*)val;
    }


    inline char* GetParsedHeaderValue(int iParsedHeaderIndex) {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 60, iParsedHeaderIndex, 0);
      return (char*)val;
    }


    inline char* GetPassword() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 61, 0, 0);
      return (char*)val;
    }

    inline int SetPassword(const char *lpPassword) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 61, 0, (void*)lpPassword, 0);
    }

    inline int GetPriority() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 62, 0, 0);
      return (int)(long)val;
    }
    inline int SetPriority(int iPriority) {
      void* val = (void*)IPS64CAST(iPriority);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 62, 0, val, 0);
    }
    inline int GetProxyAuthScheme() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 63, 0, 0);
      return (int)(long)val;
    }
    inline int SetProxyAuthScheme(int iProxyAuthScheme) {
      void* val = (void*)IPS64CAST(iProxyAuthScheme);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 63, 0, val, 0);
    }
    inline int GetProxyAutoDetect() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 64, 0, 0);
      return (int)(long)val;
    }
    inline int SetProxyAutoDetect(int bProxyAutoDetect) {
      void* val = (void*)IPS64CAST(bProxyAutoDetect);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 64, 0, val, 0);
    }
    inline char* GetProxyPassword() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 65, 0, 0);
      return (char*)val;
    }

    inline int SetProxyPassword(const char *lpProxyPassword) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 65, 0, (void*)lpProxyPassword, 0);
    }

    inline int GetProxyPort() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 66, 0, 0);
      return (int)(long)val;
    }
    inline int SetProxyPort(int lProxyPort) {
      void* val = (void*)IPS64CAST(lProxyPort);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 66, 0, val, 0);
    }
    inline char* GetProxyServer() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 67, 0, 0);
      return (char*)val;
    }

    inline int SetProxyServer(const char *lpProxyServer) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 67, 0, (void*)lpProxyServer, 0);
    }

    inline int GetProxySSL() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 68, 0, 0);
      return (int)(long)val;
    }
    inline int SetProxySSL(int iProxySSL) {
      void* val = (void*)IPS64CAST(iProxySSL);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 68, 0, val, 0);
    }
    inline char* GetProxyUser() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 69, 0, 0);
      return (char*)val;
    }

    inline int SetProxyUser(const char *lpProxyUser) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 69, 0, (void*)lpProxyUser, 0);
    }

    inline char* GetRecurrenceDates() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 70, 0, 0);
      return (char*)val;
    }

    inline int SetRecurrenceDates(const char *lpRecurrenceDates) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 70, 0, (void*)lpRecurrenceDates, 0);
    }

    inline char* GetRecurrenceExceptionDates() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 71, 0, 0);
      return (char*)val;
    }

    inline int SetRecurrenceExceptionDates(const char *lpRecurrenceExceptionDates) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 71, 0, (void*)lpRecurrenceExceptionDates, 0);
    }

    inline char* GetRecurrenceExceptionRule() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 72, 0, 0);
      return (char*)val;
    }

    inline int SetRecurrenceExceptionRule(const char *lpRecurrenceExceptionRule) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 72, 0, (void*)lpRecurrenceExceptionRule, 0);
    }

    inline char* GetRecurrenceId() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 73, 0, 0);
      return (char*)val;
    }

    inline int SetRecurrenceId(const char *lpRecurrenceId) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 73, 0, (void*)lpRecurrenceId, 0);
    }

    inline char* GetRecurrenceRule() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 74, 0, 0);
      return (char*)val;
    }

    inline int SetRecurrenceRule(const char *lpRecurrenceRule) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 74, 0, (void*)lpRecurrenceRule, 0);
    }

    inline char* GetReportFilterAlarmEnd() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 75, 0, 0);
      return (char*)val;
    }

    inline int SetReportFilterAlarmEnd(const char *lpReportFilterAlarmEnd) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 75, 0, (void*)lpReportFilterAlarmEnd, 0);
    }

    inline char* GetReportFilterAlarmStart() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 76, 0, 0);
      return (char*)val;
    }

    inline int SetReportFilterAlarmStart(const char *lpReportFilterAlarmStart) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 76, 0, (void*)lpReportFilterAlarmStart, 0);
    }

    inline char* GetReportFilterCustomFilter() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 77, 0, 0);
      return (char*)val;
    }

    inline int SetReportFilterCustomFilter(const char *lpReportFilterCustomFilter) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 77, 0, (void*)lpReportFilterCustomFilter, 0);
    }

    inline char* GetReportFilterEndDate() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 78, 0, 0);
      return (char*)val;
    }

    inline int SetReportFilterEndDate(const char *lpReportFilterEndDate) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 78, 0, (void*)lpReportFilterEndDate, 0);
    }

    inline int GetReportFilterEventType() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 79, 0, 0);
      return (int)(long)val;
    }
    inline int SetReportFilterEventType(int iReportFilterEventType) {
      void* val = (void*)IPS64CAST(iReportFilterEventType);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 79, 0, val, 0);
    }
    inline char* GetReportFilterProperty() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 80, 0, 0);
      return (char*)val;
    }

    inline int SetReportFilterProperty(const char *lpReportFilterProperty) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 80, 0, (void*)lpReportFilterProperty, 0);
    }

    inline char* GetReportFilterRecurEnd() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 81, 0, 0);
      return (char*)val;
    }

    inline int SetReportFilterRecurEnd(const char *lpReportFilterRecurEnd) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 81, 0, (void*)lpReportFilterRecurEnd, 0);
    }

    inline char* GetReportFilterRecurStart() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 82, 0, 0);
      return (char*)val;
    }

    inline int SetReportFilterRecurStart(const char *lpReportFilterRecurStart) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 82, 0, (void*)lpReportFilterRecurStart, 0);
    }

    inline int GetReportFilterReturnCalendarData() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 83, 0, 0);
      return (int)(long)val;
    }
    inline int SetReportFilterReturnCalendarData(int bReportFilterReturnCalendarData) {
      void* val = (void*)IPS64CAST(bReportFilterReturnCalendarData);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 83, 0, val, 0);
    }
    inline char* GetReportFilterStartDate() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 84, 0, 0);
      return (char*)val;
    }

    inline int SetReportFilterStartDate(const char *lpReportFilterStartDate) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 84, 0, (void*)lpReportFilterStartDate, 0);
    }

    inline char* GetReportFilterUID() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 85, 0, 0);
      return (char*)val;
    }

    inline int SetReportFilterUID(const char *lpReportFilterUID) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 85, 0, (void*)lpReportFilterUID, 0);
    }

    inline int GetSequence() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 86, 0, 0);
      return (int)(long)val;
    }
    inline int SetSequence(int iSequence) {
      void* val = (void*)IPS64CAST(iSequence);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 86, 0, val, 0);
    }
    inline int GetSSLAcceptServerCertEncoded(char *&lpSSLAcceptServerCertEncoded, int &lenSSLAcceptServerCertEncoded) {
      lpSSLAcceptServerCertEncoded = (char*)IPWorksSSL_CalDAVS_Get(m_pObj, 87, 0, &lenSSLAcceptServerCertEncoded);
      return lpSSLAcceptServerCertEncoded ? 0 : lenSSLAcceptServerCertEncoded;
    }

    inline int SetSSLAcceptServerCertEncoded(const char *lpSSLAcceptServerCertEncoded, int lenSSLAcceptServerCertEncoded) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 87, 0, (void*)lpSSLAcceptServerCertEncoded, lenSSLAcceptServerCertEncoded);
    }

    inline int GetSSLCertEncoded(char *&lpSSLCertEncoded, int &lenSSLCertEncoded) {
      lpSSLCertEncoded = (char*)IPWorksSSL_CalDAVS_Get(m_pObj, 88, 0, &lenSSLCertEncoded);
      return lpSSLCertEncoded ? 0 : lenSSLCertEncoded;
    }

    inline int SetSSLCertEncoded(const char *lpSSLCertEncoded, int lenSSLCertEncoded) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 88, 0, (void*)lpSSLCertEncoded, lenSSLCertEncoded);
    }

    inline int GetSSLCertStore(char *&lpSSLCertStore, int &lenSSLCertStore) {
      lpSSLCertStore = (char*)IPWorksSSL_CalDAVS_Get(m_pObj, 89, 0, &lenSSLCertStore);
      return lpSSLCertStore ? 0 : lenSSLCertStore;
    }

    inline int SetSSLCertStore(const char *lpSSLCertStore, int lenSSLCertStore) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 89, 0, (void*)lpSSLCertStore, lenSSLCertStore);
    }

    inline char* GetSSLCertStorePassword() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 90, 0, 0);
      return (char*)val;
    }

    inline int SetSSLCertStorePassword(const char *lpSSLCertStorePassword) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 90, 0, (void*)lpSSLCertStorePassword, 0);
    }

    inline int GetSSLCertStoreType() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 91, 0, 0);
      return (int)(long)val;
    }
    inline int SetSSLCertStoreType(int iSSLCertStoreType) {
      void* val = (void*)IPS64CAST(iSSLCertStoreType);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 91, 0, val, 0);
    }
    inline char* GetSSLCertSubject() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 92, 0, 0);
      return (char*)val;
    }

    inline int SetSSLCertSubject(const char *lpSSLCertSubject) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 92, 0, (void*)lpSSLCertSubject, 0);
    }

    inline int GetSSLServerCertEncoded(char *&lpSSLServerCertEncoded, int &lenSSLServerCertEncoded) {
      lpSSLServerCertEncoded = (char*)IPWorksSSL_CalDAVS_Get(m_pObj, 93, 0, &lenSSLServerCertEncoded);
      return lpSSLServerCertEncoded ? 0 : lenSSLServerCertEncoded;
    }


    inline char* GetStartDate() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 94, 0, 0);
      return (char*)val;
    }

    inline int SetStartDate(const char *lpStartDate) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 94, 0, (void*)lpStartDate, 0);
    }

    inline char* GetStatus() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 95, 0, 0);
      return (char*)val;
    }

    inline int SetStatus(const char *lpStatus) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 95, 0, (void*)lpStatus, 0);
    }

    inline char* GetStatusLine() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 96, 0, 0);
      return (char*)val;
    }


    inline char* GetSummary() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 97, 0, 0);
      return (char*)val;
    }

    inline int SetSummary(const char *lpSummary) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 97, 0, (void*)lpSummary, 0);
    }

    inline int GetTimeout() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 98, 0, 0);
      return (int)(long)val;
    }
    inline int SetTimeout(int iTimeout) {
      void* val = (void*)IPS64CAST(iTimeout);
      return IPWorksSSL_CalDAVS_Set(m_pObj, 98, 0, val, 0);
    }
    inline char* GetTimestamp() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 99, 0, 0);
      return (char*)val;
    }

    inline int SetTimestamp(const char *lpTimestamp) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 99, 0, (void*)lpTimestamp, 0);
    }

    inline char* GetTimezoneDSTName() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 100, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneDSTName(const char *lpTimezoneDSTName) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 100, 0, (void*)lpTimezoneDSTName, 0);
    }

    inline char* GetTimezoneDSTOffsetFrom() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 101, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneDSTOffsetFrom(const char *lpTimezoneDSTOffsetFrom) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 101, 0, (void*)lpTimezoneDSTOffsetFrom, 0);
    }

    inline char* GetTimezoneDSTOffsetTo() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 102, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneDSTOffsetTo(const char *lpTimezoneDSTOffsetTo) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 102, 0, (void*)lpTimezoneDSTOffsetTo, 0);
    }

    inline char* GetTimezoneDSTRule() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 103, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneDSTRule(const char *lpTimezoneDSTRule) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 103, 0, (void*)lpTimezoneDSTRule, 0);
    }

    inline char* GetTimezoneDSTStart() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 104, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneDSTStart(const char *lpTimezoneDSTStart) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 104, 0, (void*)lpTimezoneDSTStart, 0);
    }

    inline char* GetTimezoneLastModified() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 105, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneLastModified(const char *lpTimezoneLastModified) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 105, 0, (void*)lpTimezoneLastModified, 0);
    }

    inline char* GetTimezoneStdName() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 106, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneStdName(const char *lpTimezoneStdName) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 106, 0, (void*)lpTimezoneStdName, 0);
    }

    inline char* GetTimezoneStdOffsetFrom() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 107, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneStdOffsetFrom(const char *lpTimezoneStdOffsetFrom) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 107, 0, (void*)lpTimezoneStdOffsetFrom, 0);
    }

    inline char* GetTimezoneStdOffsetTo() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 108, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneStdOffsetTo(const char *lpTimezoneStdOffsetTo) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 108, 0, (void*)lpTimezoneStdOffsetTo, 0);
    }

    inline char* GetTimezoneStdRule() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 109, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneStdRule(const char *lpTimezoneStdRule) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 109, 0, (void*)lpTimezoneStdRule, 0);
    }

    inline char* GetTimezoneStdStart() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 110, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneStdStart(const char *lpTimezoneStdStart) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 110, 0, (void*)lpTimezoneStdStart, 0);
    }

    inline char* GetTimezoneId() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 111, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneId(const char *lpTimezoneId) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 111, 0, (void*)lpTimezoneId, 0);
    }

    inline char* GetTimezoneURL() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 112, 0, 0);
      return (char*)val;
    }

    inline int SetTimezoneURL(const char *lpTimezoneURL) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 112, 0, (void*)lpTimezoneURL, 0);
    }

    inline char* GetTransparency() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 113, 0, 0);
      return (char*)val;
    }

    inline int SetTransparency(const char *lpTransparency) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 113, 0, (void*)lpTransparency, 0);
    }

    inline char* GetUID() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 114, 0, 0);
      return (char*)val;
    }

    inline int SetUID(const char *lpUID) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 114, 0, (void*)lpUID, 0);
    }

    inline char* GetURL() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 115, 0, 0);
      return (char*)val;
    }


    inline char* GetUser() {
      void* val = IPWorksSSL_CalDAVS_Get(m_pObj, 116, 0, 0);
      return (char*)val;
    }

    inline int SetUser(const char *lpUser) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 116, 0, (void*)lpUser, 0);
    }


  public: //methods

    inline int AddCookie(const char* lpszCookieName, const char* lpszCookieValue) {
      void *param[2+1] = {(void*)IPS64CAST(lpszCookieName), (void*)IPS64CAST(lpszCookieValue), 0};
      int cbparam[2+1] = {0, 0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 2, 2, param, cbparam);
      
      
    }
    inline int AddCustomProperty(const char* lpszVarName, const char* lpszVarValue) {
      void *param[2+1] = {(void*)IPS64CAST(lpszVarName), (void*)IPS64CAST(lpszVarValue), 0};
      int cbparam[2+1] = {0, 0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 3, 2, param, cbparam);
      
      
    }
    inline char* Config(const char* lpszConfigurationString) {
      void *param[1+1] = {(void*)IPS64CAST(lpszConfigurationString), 0};
      int cbparam[1+1] = {0, 0};
      IPWorksSSL_CalDAVS_Do(m_pObj, 4, 1, param, cbparam);
      
      return (char*)IPS64CAST(param[1]);
    }
    inline int CopyCalendarEvent(const char* lpszSourceResourceURI, const char* lpszDestinationResourceURI) {
      void *param[2+1] = {(void*)IPS64CAST(lpszSourceResourceURI), (void*)IPS64CAST(lpszDestinationResourceURI), 0};
      int cbparam[2+1] = {0, 0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 5, 2, param, cbparam);
      
      
    }
    inline int CreateCalendar(const char* lpszResourceURI) {
      void *param[1+1] = {(void*)IPS64CAST(lpszResourceURI), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 6, 1, param, cbparam);
      
      
    }
    inline int DeleteCalendarEvent(const char* lpszResourceURI) {
      void *param[1+1] = {(void*)IPS64CAST(lpszResourceURI), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 7, 1, param, cbparam);
      
      
    }
    inline int DoEvents() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 8, 0, param, cbparam);
      
      
    }
    inline char* ExportICS() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      IPWorksSSL_CalDAVS_Do(m_pObj, 9, 0, param, cbparam);
      
      return (char*)IPS64CAST(param[0]);
    }
    inline int GetCalendarEvent(const char* lpszResourceURI) {
      void *param[1+1] = {(void*)IPS64CAST(lpszResourceURI), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10, 1, param, cbparam);
      
      
    }
    inline int GetCalendarOptions(const char* lpszResourceURI) {
      void *param[1+1] = {(void*)IPS64CAST(lpszResourceURI), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 11, 1, param, cbparam);
      
      
    }
    inline int GetCalendarReport(const char* lpszResourceURI) {
      void *param[1+1] = {(void*)IPS64CAST(lpszResourceURI), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 12, 1, param, cbparam);
      
      
    }
    inline int GetFreeBusyReport(const char* lpszResourceURI) {
      void *param[1+1] = {(void*)IPS64CAST(lpszResourceURI), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 13, 1, param, cbparam);
      
      
    }
    inline int ImportICS(const char* lpszCalendarData) {
      void *param[1+1] = {(void*)IPS64CAST(lpszCalendarData), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 14, 1, param, cbparam);
      
      
    }
    inline int Interrupt() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 15, 0, param, cbparam);
      
      
    }
    inline int LockCalendar(const char* lpszResourceURI) {
      void *param[1+1] = {(void*)IPS64CAST(lpszResourceURI), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 16, 1, param, cbparam);
      
      
    }
    inline int MoveCalendarEvent(const char* lpszSourceResourceURI, const char* lpszDestinationResourceURI) {
      void *param[2+1] = {(void*)IPS64CAST(lpszSourceResourceURI), (void*)IPS64CAST(lpszDestinationResourceURI), 0};
      int cbparam[2+1] = {0, 0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 17, 2, param, cbparam);
      
      
    }
    inline int PutCalendarEvent(const char* lpszResourceURI) {
      void *param[1+1] = {(void*)IPS64CAST(lpszResourceURI), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 18, 1, param, cbparam);
      
      
    }
    inline int Reset() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 19, 0, param, cbparam);
      
      
    }
    inline int UnLockCalendar(const char* lpszResourceURI) {
      void *param[1+1] = {(void*)IPS64CAST(lpszResourceURI), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 20, 1, param, cbparam);
      
      
    }

};


#ifdef WIN32 //UNICODE

typedef struct {
  int StatusCode;
  LPWSTR Description;
  int reserved;
} CalDAVSConnectedEventParamsW;

typedef struct {
  LPWSTR ConnectionEvent;
  int StatusCode;
  LPWSTR Description;
  int reserved;
} CalDAVSConnectionStatusEventParamsW;

typedef struct {
  int StatusCode;
  LPWSTR Description;
  int reserved;
} CalDAVSDisconnectedEventParamsW;

typedef struct {
  int Direction;
  int reserved;
} CalDAVSEndTransferEventParamsW;

typedef struct {
  int ErrorCode;
  LPWSTR Description;
  int reserved;
} CalDAVSErrorEventParamsW;

typedef struct {
  LPWSTR ResourceURI;
  LPWSTR ResponseStatus;
  LPWSTR ETag;
  LPWSTR CalendarData;
  int reserved;
} CalDAVSEventDetailsEventParamsW;

typedef struct {
  LPWSTR BusyType;
  LPWSTR BusyRange;
  int reserved;
} CalDAVSFreeBusyEventParamsW;

typedef struct {
  LPWSTR Field;
  LPWSTR Value;
  int reserved;
} CalDAVSHeaderEventParamsW;

typedef struct {
  LPWSTR Location;
  int Accept;
  int reserved;
} CalDAVSRedirectEventParamsW;

typedef struct {
  LPWSTR Name;
  LPWSTR Value;
  LPWSTR Expires;
  LPWSTR Domain;
  LPWSTR Path;
  int Secure;
  int reserved;
} CalDAVSSetCookieEventParamsW;

typedef struct {
  LPWSTR CertEncoded;
  LPWSTR CertSubject;
  LPWSTR CertIssuer;
  LPWSTR Status;
  int Accept;
  int lenCertEncoded;
  int reserved;
} CalDAVSSSLServerAuthenticationEventParamsW;

typedef struct {
  LPWSTR Message;
  int reserved;
} CalDAVSSSLStatusEventParamsW;

typedef struct {
  int Direction;
  int reserved;
} CalDAVSStartTransferEventParamsW;

typedef struct {
  LPWSTR HTTPVersion;
  int StatusCode;
  LPWSTR Description;
  int reserved;
} CalDAVSStatusEventParamsW;

typedef struct {
  int Direction;
  ns_int64 *pBytesTransferred;
  int PercentDone;
  LPWSTR Text;
  int lenText;
  int reserved;
} CalDAVSTransferEventParamsW;



class CalDAVSW : public CalDAVS {

  public: //properties
  




    inline LPWSTR GetAlarmAttachment(int iAlarmIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+3, iAlarmIndex, 0);
    }

    inline int SetAlarmAttachment(int iAlarmIndex, LPWSTR lpAlarmAttachment) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+3, iAlarmIndex, (void*)lpAlarmAttachment, 0);
    }

    inline LPWSTR GetAlarmAttachmentType(int iAlarmIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+4, iAlarmIndex, 0);
    }

    inline int SetAlarmAttachmentType(int iAlarmIndex, LPWSTR lpAlarmAttachmentType) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+4, iAlarmIndex, (void*)lpAlarmAttachmentType, 0);
    }

    inline LPWSTR GetAlarmDuration(int iAlarmIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+5, iAlarmIndex, 0);
    }

    inline int SetAlarmDuration(int iAlarmIndex, LPWSTR lpAlarmDuration) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+5, iAlarmIndex, (void*)lpAlarmDuration, 0);
    }

    inline LPWSTR GetAlarmMessage(int iAlarmIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+6, iAlarmIndex, 0);
    }

    inline int SetAlarmMessage(int iAlarmIndex, LPWSTR lpAlarmMessage) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+6, iAlarmIndex, (void*)lpAlarmMessage, 0);
    }

    inline LPWSTR GetAlarmRecipient(int iAlarmIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+7, iAlarmIndex, 0);
    }

    inline int SetAlarmRecipient(int iAlarmIndex, LPWSTR lpAlarmRecipient) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+7, iAlarmIndex, (void*)lpAlarmRecipient, 0);
    }



    inline LPWSTR GetAlarmSubject(int iAlarmIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+9, iAlarmIndex, 0);
    }

    inline int SetAlarmSubject(int iAlarmIndex, LPWSTR lpAlarmSubject) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+9, iAlarmIndex, (void*)lpAlarmSubject, 0);
    }

    inline LPWSTR GetAlarmTrigger(int iAlarmIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+10, iAlarmIndex, 0);
    }

    inline int SetAlarmTrigger(int iAlarmIndex, LPWSTR lpAlarmTrigger) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+10, iAlarmIndex, (void*)lpAlarmTrigger, 0);
    }

    inline LPWSTR GetAttendees() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+11, 0, 0);
    }

    inline int SetAttendees(LPWSTR lpAttendees) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+11, 0, (void*)lpAttendees, 0);
    }

    inline LPWSTR GetAuthorization() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+12, 0, 0);
    }

    inline int SetAuthorization(LPWSTR lpAuthorization) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+12, 0, (void*)lpAuthorization, 0);
    }



    inline LPWSTR GetCategories() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+14, 0, 0);
    }

    inline int SetCategories(LPWSTR lpCategories) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+14, 0, (void*)lpCategories, 0);
    }

    inline LPWSTR GetClassification() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+15, 0, 0);
    }

    inline int SetClassification(LPWSTR lpClassification) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+15, 0, (void*)lpClassification, 0);
    }

    inline LPWSTR GetCompleted() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+16, 0, 0);
    }

    inline int SetCompleted(LPWSTR lpCompleted) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+16, 0, (void*)lpCompleted, 0);
    }





    inline LPWSTR GetCookieDomain(int iCookieIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+19, iCookieIndex, 0);
    }



    inline LPWSTR GetCookieExpiration(int iCookieIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+20, iCookieIndex, 0);
    }



    inline LPWSTR GetCookieName(int iCookieIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+21, iCookieIndex, 0);
    }

    inline int SetCookieName(int iCookieIndex, LPWSTR lpCookieName) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+21, iCookieIndex, (void*)lpCookieName, 0);
    }

    inline LPWSTR GetCookiePath(int iCookieIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+22, iCookieIndex, 0);
    }





    inline LPWSTR GetCookieValue(int iCookieIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+24, iCookieIndex, 0);
    }

    inline int SetCookieValue(int iCookieIndex, LPWSTR lpCookieValue) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+24, iCookieIndex, (void*)lpCookieValue, 0);
    }

    inline LPWSTR GetCreated() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+25, 0, 0);
    }

    inline int SetCreated(LPWSTR lpCreated) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+25, 0, (void*)lpCreated, 0);
    }



    inline LPWSTR GetCustomPropertyAttribute(int iCustomPropertyIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+27, iCustomPropertyIndex, 0);
    }

    inline int SetCustomPropertyAttribute(int iCustomPropertyIndex, LPWSTR lpCustomPropertyAttribute) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+27, iCustomPropertyIndex, (void*)lpCustomPropertyAttribute, 0);
    }

    inline LPWSTR GetCustomPropertyName(int iCustomPropertyIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+28, iCustomPropertyIndex, 0);
    }

    inline int SetCustomPropertyName(int iCustomPropertyIndex, LPWSTR lpCustomPropertyName) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+28, iCustomPropertyIndex, (void*)lpCustomPropertyName, 0);
    }

    inline LPWSTR GetCustomPropertyValue(int iCustomPropertyIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+29, iCustomPropertyIndex, 0);
    }

    inline int SetCustomPropertyValue(int iCustomPropertyIndex, LPWSTR lpCustomPropertyValue) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+29, iCustomPropertyIndex, (void*)lpCustomPropertyValue, 0);
    }



    inline LPWSTR GetDescription() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+31, 0, 0);
    }

    inline int SetDescription(LPWSTR lpDescription) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+31, 0, (void*)lpDescription, 0);
    }

    inline LPWSTR GetDisplayName() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+32, 0, 0);
    }

    inline int SetDisplayName(LPWSTR lpDisplayName) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+32, 0, (void*)lpDisplayName, 0);
    }

    inline LPWSTR GetDuration() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+33, 0, 0);
    }

    inline int SetDuration(LPWSTR lpDuration) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+33, 0, (void*)lpDuration, 0);
    }

    inline LPWSTR GetEndDate() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+34, 0, 0);
    }

    inline int SetEndDate(LPWSTR lpEndDate) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+34, 0, (void*)lpEndDate, 0);
    }

    inline LPWSTR GetETag() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+35, 0, 0);
    }

    inline int SetETag(LPWSTR lpETag) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+35, 0, (void*)lpETag, 0);
    }







    inline LPWSTR GetFirewallHost() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+39, 0, 0);
    }

    inline int SetFirewallHost(LPWSTR lpFirewallHost) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+39, 0, (void*)lpFirewallHost, 0);
    }

    inline LPWSTR GetFirewallPassword() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+40, 0, 0);
    }

    inline int SetFirewallPassword(LPWSTR lpFirewallPassword) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+40, 0, (void*)lpFirewallPassword, 0);
    }



    inline LPWSTR GetFirewallUser() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+42, 0, 0);
    }

    inline int SetFirewallUser(LPWSTR lpFirewallUser) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+42, 0, (void*)lpFirewallUser, 0);
    }





    inline LPWSTR GetFreeBusyRange(int iFreeBusyIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+45, iFreeBusyIndex, 0);
    }



    inline LPWSTR GetFreeBusyType(int iFreeBusyIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+46, iFreeBusyIndex, 0);
    }





    inline LPWSTR GetLastModified() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+48, 0, 0);
    }

    inline int SetLastModified(LPWSTR lpLastModified) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+48, 0, (void*)lpLastModified, 0);
    }

    inline LPWSTR GetLocalHost() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+49, 0, 0);
    }

    inline int SetLocalHost(LPWSTR lpLocalHost) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+49, 0, (void*)lpLocalHost, 0);
    }

    inline LPWSTR GetLocation() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+50, 0, 0);
    }

    inline int SetLocation(LPWSTR lpLocation) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+50, 0, (void*)lpLocation, 0);
    }

    inline LPWSTR GetLockType() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+51, 0, 0);
    }

    inline int SetLockType(LPWSTR lpLockType) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+51, 0, (void*)lpLockType, 0);
    }

    inline LPWSTR GetLockOwner() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+52, 0, 0);
    }

    inline int SetLockOwner(LPWSTR lpLockOwner) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+52, 0, (void*)lpLockOwner, 0);
    }

    inline LPWSTR GetLockScope() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+53, 0, 0);
    }

    inline int SetLockScope(LPWSTR lpLockScope) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+53, 0, (void*)lpLockScope, 0);
    }



    inline LPWSTR GetLockTokens() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+55, 0, 0);
    }

    inline int SetLockTokens(LPWSTR lpLockTokens) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+55, 0, (void*)lpLockTokens, 0);
    }

    inline LPWSTR GetOrganizer() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+56, 0, 0);
    }

    inline int SetOrganizer(LPWSTR lpOrganizer) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+56, 0, (void*)lpOrganizer, 0);
    }

    inline LPWSTR GetOtherHeaders() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+57, 0, 0);
    }

    inline int SetOtherHeaders(LPWSTR lpOtherHeaders) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+57, 0, (void*)lpOtherHeaders, 0);
    }



    inline LPWSTR GetParsedHeaderField(int iParsedHeaderIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+59, iParsedHeaderIndex, 0);
    }



    inline LPWSTR GetParsedHeaderValue(int iParsedHeaderIndex) {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+60, iParsedHeaderIndex, 0);
    }



    inline LPWSTR GetPassword() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+61, 0, 0);
    }

    inline int SetPassword(LPWSTR lpPassword) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+61, 0, (void*)lpPassword, 0);
    }







    inline LPWSTR GetProxyPassword() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+65, 0, 0);
    }

    inline int SetProxyPassword(LPWSTR lpProxyPassword) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+65, 0, (void*)lpProxyPassword, 0);
    }



    inline LPWSTR GetProxyServer() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+67, 0, 0);
    }

    inline int SetProxyServer(LPWSTR lpProxyServer) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+67, 0, (void*)lpProxyServer, 0);
    }



    inline LPWSTR GetProxyUser() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+69, 0, 0);
    }

    inline int SetProxyUser(LPWSTR lpProxyUser) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+69, 0, (void*)lpProxyUser, 0);
    }

    inline LPWSTR GetRecurrenceDates() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+70, 0, 0);
    }

    inline int SetRecurrenceDates(LPWSTR lpRecurrenceDates) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+70, 0, (void*)lpRecurrenceDates, 0);
    }

    inline LPWSTR GetRecurrenceExceptionDates() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+71, 0, 0);
    }

    inline int SetRecurrenceExceptionDates(LPWSTR lpRecurrenceExceptionDates) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+71, 0, (void*)lpRecurrenceExceptionDates, 0);
    }

    inline LPWSTR GetRecurrenceExceptionRule() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+72, 0, 0);
    }

    inline int SetRecurrenceExceptionRule(LPWSTR lpRecurrenceExceptionRule) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+72, 0, (void*)lpRecurrenceExceptionRule, 0);
    }

    inline LPWSTR GetRecurrenceId() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+73, 0, 0);
    }

    inline int SetRecurrenceId(LPWSTR lpRecurrenceId) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+73, 0, (void*)lpRecurrenceId, 0);
    }

    inline LPWSTR GetRecurrenceRule() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+74, 0, 0);
    }

    inline int SetRecurrenceRule(LPWSTR lpRecurrenceRule) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+74, 0, (void*)lpRecurrenceRule, 0);
    }

    inline LPWSTR GetReportFilterAlarmEnd() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+75, 0, 0);
    }

    inline int SetReportFilterAlarmEnd(LPWSTR lpReportFilterAlarmEnd) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+75, 0, (void*)lpReportFilterAlarmEnd, 0);
    }

    inline LPWSTR GetReportFilterAlarmStart() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+76, 0, 0);
    }

    inline int SetReportFilterAlarmStart(LPWSTR lpReportFilterAlarmStart) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+76, 0, (void*)lpReportFilterAlarmStart, 0);
    }

    inline LPWSTR GetReportFilterCustomFilter() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+77, 0, 0);
    }

    inline int SetReportFilterCustomFilter(LPWSTR lpReportFilterCustomFilter) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+77, 0, (void*)lpReportFilterCustomFilter, 0);
    }

    inline LPWSTR GetReportFilterEndDate() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+78, 0, 0);
    }

    inline int SetReportFilterEndDate(LPWSTR lpReportFilterEndDate) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+78, 0, (void*)lpReportFilterEndDate, 0);
    }



    inline LPWSTR GetReportFilterProperty() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+80, 0, 0);
    }

    inline int SetReportFilterProperty(LPWSTR lpReportFilterProperty) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+80, 0, (void*)lpReportFilterProperty, 0);
    }

    inline LPWSTR GetReportFilterRecurEnd() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+81, 0, 0);
    }

    inline int SetReportFilterRecurEnd(LPWSTR lpReportFilterRecurEnd) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+81, 0, (void*)lpReportFilterRecurEnd, 0);
    }

    inline LPWSTR GetReportFilterRecurStart() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+82, 0, 0);
    }

    inline int SetReportFilterRecurStart(LPWSTR lpReportFilterRecurStart) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+82, 0, (void*)lpReportFilterRecurStart, 0);
    }



    inline LPWSTR GetReportFilterStartDate() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+84, 0, 0);
    }

    inline int SetReportFilterStartDate(LPWSTR lpReportFilterStartDate) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+84, 0, (void*)lpReportFilterStartDate, 0);
    }

    inline LPWSTR GetReportFilterUID() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+85, 0, 0);
    }

    inline int SetReportFilterUID(LPWSTR lpReportFilterUID) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+85, 0, (void*)lpReportFilterUID, 0);
    }



    inline LPWSTR GetSSLAcceptServerCertEncoded() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+87, 0, 0);
    }

    inline int SetSSLAcceptServerCertEncoded(LPWSTR lpSSLAcceptServerCertEncoded) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+87, 0, (void*)lpSSLAcceptServerCertEncoded, 0);
    }
    inline int GetSSLAcceptServerCertEncodedB(char *&lpSSLAcceptServerCertEncoded, int &lenSSLAcceptServerCertEncoded) {
      lpSSLAcceptServerCertEncoded = (char*)IPWorksSSL_CalDAVS_Get(m_pObj, 87, 0, &lenSSLAcceptServerCertEncoded);
      return lpSSLAcceptServerCertEncoded ? 0 : lenSSLAcceptServerCertEncoded;
    }
    inline int SetSSLAcceptServerCertEncodedB(const char *lpSSLAcceptServerCertEncoded, int lenSSLAcceptServerCertEncoded) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 87, 0, (void*)lpSSLAcceptServerCertEncoded, lenSSLAcceptServerCertEncoded);
    }
    inline LPWSTR GetSSLCertEncoded() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+88, 0, 0);
    }

    inline int SetSSLCertEncoded(LPWSTR lpSSLCertEncoded) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+88, 0, (void*)lpSSLCertEncoded, 0);
    }
    inline int GetSSLCertEncodedB(char *&lpSSLCertEncoded, int &lenSSLCertEncoded) {
      lpSSLCertEncoded = (char*)IPWorksSSL_CalDAVS_Get(m_pObj, 88, 0, &lenSSLCertEncoded);
      return lpSSLCertEncoded ? 0 : lenSSLCertEncoded;
    }
    inline int SetSSLCertEncodedB(const char *lpSSLCertEncoded, int lenSSLCertEncoded) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 88, 0, (void*)lpSSLCertEncoded, lenSSLCertEncoded);
    }
    inline LPWSTR GetSSLCertStore() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+89, 0, 0);
    }

    inline int SetSSLCertStore(LPWSTR lpSSLCertStore) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+89, 0, (void*)lpSSLCertStore, 0);
    }
    inline int GetSSLCertStoreB(char *&lpSSLCertStore, int &lenSSLCertStore) {
      lpSSLCertStore = (char*)IPWorksSSL_CalDAVS_Get(m_pObj, 89, 0, &lenSSLCertStore);
      return lpSSLCertStore ? 0 : lenSSLCertStore;
    }
    inline int SetSSLCertStoreB(const char *lpSSLCertStore, int lenSSLCertStore) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 89, 0, (void*)lpSSLCertStore, lenSSLCertStore);
    }
    inline LPWSTR GetSSLCertStorePassword() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+90, 0, 0);
    }

    inline int SetSSLCertStorePassword(LPWSTR lpSSLCertStorePassword) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+90, 0, (void*)lpSSLCertStorePassword, 0);
    }



    inline LPWSTR GetSSLCertSubject() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+92, 0, 0);
    }

    inline int SetSSLCertSubject(LPWSTR lpSSLCertSubject) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+92, 0, (void*)lpSSLCertSubject, 0);
    }

    inline LPWSTR GetSSLServerCertEncoded() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+93, 0, 0);
    }


    inline int GetSSLServerCertEncodedB(char *&lpSSLServerCertEncoded, int &lenSSLServerCertEncoded) {
      lpSSLServerCertEncoded = (char*)IPWorksSSL_CalDAVS_Get(m_pObj, 93, 0, &lenSSLServerCertEncoded);
      return lpSSLServerCertEncoded ? 0 : lenSSLServerCertEncoded;
    }

    inline LPWSTR GetStartDate() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+94, 0, 0);
    }

    inline int SetStartDate(LPWSTR lpStartDate) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+94, 0, (void*)lpStartDate, 0);
    }

    inline LPWSTR GetStatus() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+95, 0, 0);
    }

    inline int SetStatus(LPWSTR lpStatus) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+95, 0, (void*)lpStatus, 0);
    }

    inline LPWSTR GetStatusLine() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+96, 0, 0);
    }



    inline LPWSTR GetSummary() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+97, 0, 0);
    }

    inline int SetSummary(LPWSTR lpSummary) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+97, 0, (void*)lpSummary, 0);
    }



    inline LPWSTR GetTimestamp() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+99, 0, 0);
    }

    inline int SetTimestamp(LPWSTR lpTimestamp) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+99, 0, (void*)lpTimestamp, 0);
    }

    inline LPWSTR GetTimezoneDSTName() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+100, 0, 0);
    }

    inline int SetTimezoneDSTName(LPWSTR lpTimezoneDSTName) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+100, 0, (void*)lpTimezoneDSTName, 0);
    }

    inline LPWSTR GetTimezoneDSTOffsetFrom() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+101, 0, 0);
    }

    inline int SetTimezoneDSTOffsetFrom(LPWSTR lpTimezoneDSTOffsetFrom) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+101, 0, (void*)lpTimezoneDSTOffsetFrom, 0);
    }

    inline LPWSTR GetTimezoneDSTOffsetTo() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+102, 0, 0);
    }

    inline int SetTimezoneDSTOffsetTo(LPWSTR lpTimezoneDSTOffsetTo) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+102, 0, (void*)lpTimezoneDSTOffsetTo, 0);
    }

    inline LPWSTR GetTimezoneDSTRule() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+103, 0, 0);
    }

    inline int SetTimezoneDSTRule(LPWSTR lpTimezoneDSTRule) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+103, 0, (void*)lpTimezoneDSTRule, 0);
    }

    inline LPWSTR GetTimezoneDSTStart() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+104, 0, 0);
    }

    inline int SetTimezoneDSTStart(LPWSTR lpTimezoneDSTStart) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+104, 0, (void*)lpTimezoneDSTStart, 0);
    }

    inline LPWSTR GetTimezoneLastModified() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+105, 0, 0);
    }

    inline int SetTimezoneLastModified(LPWSTR lpTimezoneLastModified) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+105, 0, (void*)lpTimezoneLastModified, 0);
    }

    inline LPWSTR GetTimezoneStdName() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+106, 0, 0);
    }

    inline int SetTimezoneStdName(LPWSTR lpTimezoneStdName) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+106, 0, (void*)lpTimezoneStdName, 0);
    }

    inline LPWSTR GetTimezoneStdOffsetFrom() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+107, 0, 0);
    }

    inline int SetTimezoneStdOffsetFrom(LPWSTR lpTimezoneStdOffsetFrom) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+107, 0, (void*)lpTimezoneStdOffsetFrom, 0);
    }

    inline LPWSTR GetTimezoneStdOffsetTo() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+108, 0, 0);
    }

    inline int SetTimezoneStdOffsetTo(LPWSTR lpTimezoneStdOffsetTo) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+108, 0, (void*)lpTimezoneStdOffsetTo, 0);
    }

    inline LPWSTR GetTimezoneStdRule() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+109, 0, 0);
    }

    inline int SetTimezoneStdRule(LPWSTR lpTimezoneStdRule) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+109, 0, (void*)lpTimezoneStdRule, 0);
    }

    inline LPWSTR GetTimezoneStdStart() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+110, 0, 0);
    }

    inline int SetTimezoneStdStart(LPWSTR lpTimezoneStdStart) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+110, 0, (void*)lpTimezoneStdStart, 0);
    }

    inline LPWSTR GetTimezoneId() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+111, 0, 0);
    }

    inline int SetTimezoneId(LPWSTR lpTimezoneId) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+111, 0, (void*)lpTimezoneId, 0);
    }

    inline LPWSTR GetTimezoneURL() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+112, 0, 0);
    }

    inline int SetTimezoneURL(LPWSTR lpTimezoneURL) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+112, 0, (void*)lpTimezoneURL, 0);
    }

    inline LPWSTR GetTransparency() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+113, 0, 0);
    }

    inline int SetTransparency(LPWSTR lpTransparency) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+113, 0, (void*)lpTransparency, 0);
    }

    inline LPWSTR GetUID() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+114, 0, 0);
    }

    inline int SetUID(LPWSTR lpUID) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+114, 0, (void*)lpUID, 0);
    }

    inline LPWSTR GetURL() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+115, 0, 0);
    }



    inline LPWSTR GetUser() {
      return (LPWSTR)IPWorksSSL_CalDAVS_Get(m_pObj, 10000+116, 0, 0);
    }

    inline int SetUser(LPWSTR lpUser) {
      return IPWorksSSL_CalDAVS_Set(m_pObj, 10000+116, 0, (void*)lpUser, 0);
    }



  public: //events
  
    virtual int FireConnected(CalDAVSConnectedEventParamsW *e) {return 0;}
    virtual int FireConnectionStatus(CalDAVSConnectionStatusEventParamsW *e) {return 0;}
    virtual int FireDisconnected(CalDAVSDisconnectedEventParamsW *e) {return 0;}
    virtual int FireEndTransfer(CalDAVSEndTransferEventParamsW *e) {return 0;}
    virtual int FireError(CalDAVSErrorEventParamsW *e) {return 0;}
    virtual int FireEventDetails(CalDAVSEventDetailsEventParamsW *e) {return 0;}
    virtual int FireFreeBusy(CalDAVSFreeBusyEventParamsW *e) {return 0;}
    virtual int FireHeader(CalDAVSHeaderEventParamsW *e) {return 0;}
    virtual int FireRedirect(CalDAVSRedirectEventParamsW *e) {return 0;}
    virtual int FireSetCookie(CalDAVSSetCookieEventParamsW *e) {return 0;}
    virtual int FireSSLServerAuthentication(CalDAVSSSLServerAuthenticationEventParamsW *e) {return 0;}
    virtual int FireSSLStatus(CalDAVSSSLStatusEventParamsW *e) {return 0;}
    virtual int FireStartTransfer(CalDAVSStartTransferEventParamsW *e) {return 0;}
    virtual int FireStatus(CalDAVSStatusEventParamsW *e) {return 0;}
    virtual int FireTransfer(CalDAVSTransferEventParamsW *e) {return 0;}


  protected:
  
    virtual int CalDAVSEventSinkW(int event_id, int cparam, void *param[], int cbparam[]) {
    	int ret_code = 0;
      switch (event_id) {
         case 1: {
            CalDAVSConnectedEventParamsW e = {(int)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]),  0};
            ret_code = FireConnected(&e);
            break;
         }
         case 2: {
            CalDAVSConnectionStatusEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (int)IPS64CAST(param[1]), (LPWSTR)IPS64CAST(param[2]),  0};
            ret_code = FireConnectionStatus(&e);
            break;
         }
         case 3: {
            CalDAVSDisconnectedEventParamsW e = {(int)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]),  0};
            ret_code = FireDisconnected(&e);
            break;
         }
         case 4: {
            CalDAVSEndTransferEventParamsW e = {(int)IPS64CAST(param[0]),  0};
            ret_code = FireEndTransfer(&e);
            break;
         }
         case 5: {
            CalDAVSErrorEventParamsW e = {(int)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]),  0};
            ret_code = FireError(&e);
            break;
         }
         case 6: {
            CalDAVSEventDetailsEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]), (LPWSTR)IPS64CAST(param[2]), (LPWSTR)IPS64CAST(param[3]),  0};
            ret_code = FireEventDetails(&e);
            break;
         }
         case 7: {
            CalDAVSFreeBusyEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]),  0};
            ret_code = FireFreeBusy(&e);
            break;
         }
         case 8: {
            CalDAVSHeaderEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]),  0};
            ret_code = FireHeader(&e);
            break;
         }
         case 9: {
            CalDAVSRedirectEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (int)IPS64CAST(param[1]),  0};
            ret_code = FireRedirect(&e);
            param[1] = (void*)(e.Accept);
            break;
         }
         case 10: {
            CalDAVSSetCookieEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]), (LPWSTR)IPS64CAST(param[2]), (LPWSTR)IPS64CAST(param[3]), (LPWSTR)IPS64CAST(param[4]), (int)IPS64CAST(param[5]),  0};
            ret_code = FireSetCookie(&e);
            break;
         }
         case 11: {
            CalDAVSSSLServerAuthenticationEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]), (LPWSTR)IPS64CAST(param[2]), (LPWSTR)IPS64CAST(param[3]), (int)IPS64CAST(param[4]), (int)IPS64CAST(cbparam[0]),  0};
            ret_code = FireSSLServerAuthentication(&e);
            param[4] = (void*)(e.Accept);
            break;
         }
         case 12: {
            CalDAVSSSLStatusEventParamsW e = {(LPWSTR)IPS64CAST(param[0]),  0};
            ret_code = FireSSLStatus(&e);
            break;
         }
         case 13: {
            CalDAVSStartTransferEventParamsW e = {(int)IPS64CAST(param[0]),  0};
            ret_code = FireStartTransfer(&e);
            break;
         }
         case 14: {
            CalDAVSStatusEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (int)IPS64CAST(param[1]), (LPWSTR)IPS64CAST(param[2]),  0};
            ret_code = FireStatus(&e);
            break;
         }
         case 15: {
            CalDAVSTransferEventParamsW e = {(int)IPS64CAST(param[0]), (ns_int64*)IPS64CAST(param[1]), (int)IPS64CAST(param[2]), (LPWSTR)IPS64CAST(param[3]), (int)IPS64CAST(cbparam[3]),  0};
            ret_code = FireTransfer(&e);
            break;
         }

      }
      return ret_code;
    }
  
  public: //event overrides

    virtual int FireConnected(CalDAVSConnectedEventParams *e) {return -10000;}
    virtual int FireConnectionStatus(CalDAVSConnectionStatusEventParams *e) {return -10000;}
    virtual int FireDisconnected(CalDAVSDisconnectedEventParams *e) {return -10000;}
    virtual int FireEndTransfer(CalDAVSEndTransferEventParams *e) {return -10000;}
    virtual int FireError(CalDAVSErrorEventParams *e) {return -10000;}
    virtual int FireEventDetails(CalDAVSEventDetailsEventParams *e) {return -10000;}
    virtual int FireFreeBusy(CalDAVSFreeBusyEventParams *e) {return -10000;}
    virtual int FireHeader(CalDAVSHeaderEventParams *e) {return -10000;}
    virtual int FireRedirect(CalDAVSRedirectEventParams *e) {return -10000;}
    virtual int FireSetCookie(CalDAVSSetCookieEventParams *e) {return -10000;}
    virtual int FireSSLServerAuthentication(CalDAVSSSLServerAuthenticationEventParams *e) {return -10000;}
    virtual int FireSSLStatus(CalDAVSSSLStatusEventParams *e) {return -10000;}
    virtual int FireStartTransfer(CalDAVSStartTransferEventParams *e) {return -10000;}
    virtual int FireStatus(CalDAVSStatusEventParams *e) {return -10000;}
    virtual int FireTransfer(CalDAVSTransferEventParams *e) {return -10000;}

  public: //methods

    inline int AddCookie(LPWSTR lpszCookieName, LPWSTR lpszCookieValue) {
      void *param[2+1] = {(void*)lpszCookieName, (void*)lpszCookieValue, 0};
      int cbparam[2+1] = {0, 0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+2, 2, param, cbparam);
      
    }
    inline int AddCustomProperty(LPWSTR lpszVarName, LPWSTR lpszVarValue) {
      void *param[2+1] = {(void*)lpszVarName, (void*)lpszVarValue, 0};
      int cbparam[2+1] = {0, 0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+3, 2, param, cbparam);
      
    }
    inline LPWSTR Config(LPWSTR lpszConfigurationString) {
      void *param[1+1] = {(void*)lpszConfigurationString, 0};
      int cbparam[1+1] = {0, 0};
      IPWorksSSL_CalDAVS_Do(m_pObj, 10000+4, 1, param, cbparam);
      return (LPWSTR)IPS64CAST(param[1]);
    }
    inline int CopyCalendarEvent(LPWSTR lpszSourceResourceURI, LPWSTR lpszDestinationResourceURI) {
      void *param[2+1] = {(void*)lpszSourceResourceURI, (void*)lpszDestinationResourceURI, 0};
      int cbparam[2+1] = {0, 0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+5, 2, param, cbparam);
      
    }
    inline int CreateCalendar(LPWSTR lpszResourceURI) {
      void *param[1+1] = {(void*)lpszResourceURI, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+6, 1, param, cbparam);
      
    }
    inline int DeleteCalendarEvent(LPWSTR lpszResourceURI) {
      void *param[1+1] = {(void*)lpszResourceURI, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+7, 1, param, cbparam);
      
    }
    inline int DoEvents() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+8, 0, param, cbparam);
      
    }
    inline LPWSTR ExportICS() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      IPWorksSSL_CalDAVS_Do(m_pObj, 10000+9, 0, param, cbparam);
      return (LPWSTR)IPS64CAST(param[0]);
    }
    inline int GetCalendarEvent(LPWSTR lpszResourceURI) {
      void *param[1+1] = {(void*)lpszResourceURI, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+10, 1, param, cbparam);
      
    }
    inline int GetCalendarOptions(LPWSTR lpszResourceURI) {
      void *param[1+1] = {(void*)lpszResourceURI, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+11, 1, param, cbparam);
      
    }
    inline int GetCalendarReport(LPWSTR lpszResourceURI) {
      void *param[1+1] = {(void*)lpszResourceURI, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+12, 1, param, cbparam);
      
    }
    inline int GetFreeBusyReport(LPWSTR lpszResourceURI) {
      void *param[1+1] = {(void*)lpszResourceURI, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+13, 1, param, cbparam);
      
    }
    inline int ImportICS(LPWSTR lpszCalendarData) {
      void *param[1+1] = {(void*)lpszCalendarData, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+14, 1, param, cbparam);
      
    }
    inline int Interrupt() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+15, 0, param, cbparam);
      
    }
    inline int LockCalendar(LPWSTR lpszResourceURI) {
      void *param[1+1] = {(void*)lpszResourceURI, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+16, 1, param, cbparam);
      
    }
    inline int MoveCalendarEvent(LPWSTR lpszSourceResourceURI, LPWSTR lpszDestinationResourceURI) {
      void *param[2+1] = {(void*)lpszSourceResourceURI, (void*)lpszDestinationResourceURI, 0};
      int cbparam[2+1] = {0, 0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+17, 2, param, cbparam);
      
    }
    inline int PutCalendarEvent(LPWSTR lpszResourceURI) {
      void *param[1+1] = {(void*)lpszResourceURI, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+18, 1, param, cbparam);
      
    }
    inline int Reset() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+19, 0, param, cbparam);
      
    }
    inline int UnLockCalendar(LPWSTR lpszResourceURI) {
      void *param[1+1] = {(void*)lpszResourceURI, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_CalDAVS_Do(m_pObj, 10000+20, 1, param, cbparam);
      
    }

};

#endif //WIN32

#endif //_IPWORKSSSL_CALDAVS_H_




