/******************************************************************
   IP*Works! SSL V9 C++ Edition
   Copyright (c) 2013 /n software inc. - All rights reserved.
*******************************************************************/

#ifndef _IPWORKSSSL_IPPORTS_H_
#define _IPWORKSSSL_IPPORTS_H_

#define IPWORKSSSL_ONLY_TYPES
#include "ipworksssl.h"
#include "ipworksssl.key"

//FirewallTypes
#define FW_NONE                                            0
#define FW_TUNNEL                                          1
#define FW_SOCKS4                                          2
#define FW_SOCKS5                                          3

//CertStoreTypes
#define CST_USER                                           0
#define CST_MACHINE                                        1
#define CST_PFXFILE                                        2
#define CST_PFXBLOB                                        3
#define CST_JKSFILE                                        4
#define CST_JKSBLOB                                        5
#define CST_PEMKEY_FILE                                    6
#define CST_PEMKEY_BLOB                                    7
#define CST_PUBLIC_KEY_FILE                                8
#define CST_PUBLIC_KEY_BLOB                                9
#define CST_SSHPUBLIC_KEY_BLOB                             10
#define CST_P7BFILE                                        11
#define CST_P7BBLOB                                        12
#define CST_SSHPUBLIC_KEY_FILE                             13

//TSSLStartMode
#define SSL_AUTOMATIC                                      0
#define SSL_IMPLICIT                                       1
#define SSL_EXPLICIT                                       2
#define SSL_NONE                                           3


extern "C" void* IPWORKSSSL_CALL IPWorksSSL_IPPortS_Create(PIPWORKSSSL_CALLBACK lpSink, void *lpContext, char *lpOemKey);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_IPPortS_Destroy(void *lpObj);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_IPPortS_CheckIndex(void *lpObj, int propid, int arridx);
extern "C" void* IPWORKSSSL_CALL IPWorksSSL_IPPortS_Get(void *lpObj, int propid, int arridx, int *lpcbVal);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_IPPortS_Set(void *lpObj, int propid, int arridx, const void *val, int cbVal);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_IPPortS_Do(void *lpObj, int methid, int cparam, void *param[], int cbparam[]);
extern "C" char* IPWORKSSSL_CALL IPWorksSSL_IPPortS_GetLastError(void *lpObj);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_IPPortS_GetLastErrorCode(void *lpObj);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_IPPortS_StaticInit(void *hInst);
extern "C" int   IPWORKSSSL_CALL IPWorksSSL_IPPortS_StaticDestroy();

#ifdef WIN32
#include <windows.h>
#pragma warning(disable:4311) 
#pragma warning(disable:4312) 
#endif

typedef struct {
  int StatusCode;
  const char* Description;
  int reserved;
} IPPortSConnectedEventParams;

typedef struct {
  const char* ConnectionEvent;
  int StatusCode;
  const char* Description;
  int reserved;
} IPPortSConnectionStatusEventParams;

typedef struct {
  const char* Text;
  int EOL;
  int lenText;
  int reserved;
} IPPortSDataInEventParams;

typedef struct {
  int StatusCode;
  const char* Description;
  int reserved;
} IPPortSDisconnectedEventParams;

typedef struct {
  int ErrorCode;
  const char* Description;
  int reserved;
} IPPortSErrorEventParams;

typedef struct {
  int reserved;
} IPPortSReadyToSendEventParams;

typedef struct {
  const char* CertEncoded;
  const char* CertSubject;
  const char* CertIssuer;
  const char* Status;
  int Accept;
  int lenCertEncoded;
  int reserved;
} IPPortSSSLServerAuthenticationEventParams;

typedef struct {
  const char* Message;
  int reserved;
} IPPortSSSLStatusEventParams;



class IPPortS {
  
  public: //events
  
    virtual int FireConnected(IPPortSConnectedEventParams *e) {return 0;}
    virtual int FireConnectionStatus(IPPortSConnectionStatusEventParams *e) {return 0;}
    virtual int FireDataIn(IPPortSDataInEventParams *e) {return 0;}
    virtual int FireDisconnected(IPPortSDisconnectedEventParams *e) {return 0;}
    virtual int FireError(IPPortSErrorEventParams *e) {return 0;}
    virtual int FireReadyToSend(IPPortSReadyToSendEventParams *e) {return 0;}
    virtual int FireSSLServerAuthentication(IPPortSSSLServerAuthenticationEventParams *e) {return 0;}
    virtual int FireSSLStatus(IPPortSSSLStatusEventParams *e) {return 0;}


  protected:

    void *m_pObj;
    
    static int IPWORKSSSL_CALL IPPortSEventSink(void *lpObj, int event_id, int cparam, void *param[], int cbparam[]) {
      int ret_code = 0;
      if (event_id > 10000) return ((IPPortS*)lpObj)->IPPortSEventSinkW(event_id - 10000, cparam, param, cbparam);
      switch (event_id) {
         case 1: {
            IPPortSConnectedEventParams e = {(int)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]),  0};
            ret_code = ((IPPortS*)lpObj)->FireConnected(&e);
            break;
         }
         case 2: {
            IPPortSConnectionStatusEventParams e = {(char*)IPS64CAST(param[0]), (int)IPS64CAST(param[1]), (char*)IPS64CAST(param[2]),  0};
            ret_code = ((IPPortS*)lpObj)->FireConnectionStatus(&e);
            break;
         }
         case 3: {
            IPPortSDataInEventParams e = {(char*)IPS64CAST(param[0]), (int)IPS64CAST(param[1]), (int)IPS64CAST(cbparam[0]),  0};
            ret_code = ((IPPortS*)lpObj)->FireDataIn(&e);
            break;
         }
         case 4: {
            IPPortSDisconnectedEventParams e = {(int)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]),  0};
            ret_code = ((IPPortS*)lpObj)->FireDisconnected(&e);
            break;
         }
         case 5: {
            IPPortSErrorEventParams e = {(int)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]),  0};
            ret_code = ((IPPortS*)lpObj)->FireError(&e);
            break;
         }
         case 6: {
            IPPortSReadyToSendEventParams e = { 0};
            ret_code = ((IPPortS*)lpObj)->FireReadyToSend(&e);
            break;
         }
         case 7: {
            IPPortSSSLServerAuthenticationEventParams e = {(char*)IPS64CAST(param[0]), (char*)IPS64CAST(param[1]), (char*)IPS64CAST(param[2]), (char*)IPS64CAST(param[3]), (int)IPS64CAST(param[4]), (int)IPS64CAST(cbparam[0]),  0};
            ret_code = ((IPPortS*)lpObj)->FireSSLServerAuthentication(&e);
            param[4] = (void*)IPS64CAST(e.Accept);
            break;
         }
         case 8: {
            IPPortSSSLStatusEventParams e = {(char*)IPS64CAST(param[0]),  0};
            ret_code = ((IPPortS*)lpObj)->FireSSLStatus(&e);
            break;
         }

      }
      return ret_code;
    }

    virtual int IPPortSEventSinkW(int event_id, int cparam, void *param[], int cbparam[]) {return 0;}

  public:

    IPPortS(char *lpOemKey = (char*)IPWORKSSSL_OEMKEY_11) {
      m_pObj = IPWorksSSL_IPPortS_Create(IPPortSEventSink, (void*)this, (char*)lpOemKey);
    }

    virtual ~IPPortS() {
      IPWorksSSL_IPPortS_Destroy(m_pObj);
    }

  public:

    inline char *GetLastError() {
      return IPWorksSSL_IPPortS_GetLastError(m_pObj);
    }
    
    inline int GetLastErrorCode() {
      return IPWorksSSL_IPPortS_GetLastErrorCode(m_pObj);
    }

    inline char *VERSION() {
      return (char*)IPWorksSSL_IPPortS_Get(m_pObj, 0, 0, 0);
    }

  public: //properties

    inline int GetAcceptData() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 1, 0, 0);
      return (int)(long)val;
    }
    inline int SetAcceptData(int bAcceptData) {
      void* val = (void*)IPS64CAST(bAcceptData);
      return IPWorksSSL_IPPortS_Set(m_pObj, 1, 0, val, 0);
    }
    inline int GetBytesSent() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 2, 0, 0);
      return (int)(long)val;
    }

    inline int GetConnected() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 3, 0, 0);
      return (int)(long)val;
    }
    inline int SetConnected(int bConnected) {
      void* val = (void*)IPS64CAST(bConnected);
      return IPWorksSSL_IPPortS_Set(m_pObj, 3, 0, val, 0);
    }

    inline int SetDataToSend(const char *lpDataToSend, int lenDataToSend) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 4, 0, (void*)lpDataToSend, lenDataToSend);
    }

    inline int GetEOL(char *&lpEOL, int &lenEOL) {
      lpEOL = (char*)IPWorksSSL_IPPortS_Get(m_pObj, 5, 0, &lenEOL);
      return lpEOL ? 0 : lenEOL;
    }

    inline int SetEOL(const char *lpEOL, int lenEOL) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 5, 0, (void*)lpEOL, lenEOL);
    }

    inline int GetFirewallAutoDetect() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 6, 0, 0);
      return (int)(long)val;
    }
    inline int SetFirewallAutoDetect(int bFirewallAutoDetect) {
      void* val = (void*)IPS64CAST(bFirewallAutoDetect);
      return IPWorksSSL_IPPortS_Set(m_pObj, 6, 0, val, 0);
    }
    inline int GetFirewallType() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 7, 0, 0);
      return (int)(long)val;
    }
    inline int SetFirewallType(int iFirewallType) {
      void* val = (void*)IPS64CAST(iFirewallType);
      return IPWorksSSL_IPPortS_Set(m_pObj, 7, 0, val, 0);
    }
    inline char* GetFirewallHost() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 8, 0, 0);
      return (char*)val;
    }

    inline int SetFirewallHost(const char *lpFirewallHost) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 8, 0, (void*)lpFirewallHost, 0);
    }

    inline char* GetFirewallPassword() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 9, 0, 0);
      return (char*)val;
    }

    inline int SetFirewallPassword(const char *lpFirewallPassword) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 9, 0, (void*)lpFirewallPassword, 0);
    }

    inline int GetFirewallPort() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 10, 0, 0);
      return (int)(long)val;
    }
    inline int SetFirewallPort(int lFirewallPort) {
      void* val = (void*)IPS64CAST(lFirewallPort);
      return IPWorksSSL_IPPortS_Set(m_pObj, 10, 0, val, 0);
    }
    inline char* GetFirewallUser() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 11, 0, 0);
      return (char*)val;
    }

    inline int SetFirewallUser(const char *lpFirewallUser) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 11, 0, (void*)lpFirewallUser, 0);
    }

    inline int GetKeepAlive() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 12, 0, 0);
      return (int)(long)val;
    }
    inline int SetKeepAlive(int bKeepAlive) {
      void* val = (void*)IPS64CAST(bKeepAlive);
      return IPWorksSSL_IPPortS_Set(m_pObj, 12, 0, val, 0);
    }
    inline int GetLinger() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 13, 0, 0);
      return (int)(long)val;
    }
    inline int SetLinger(int bLinger) {
      void* val = (void*)IPS64CAST(bLinger);
      return IPWorksSSL_IPPortS_Set(m_pObj, 13, 0, val, 0);
    }
    inline char* GetLocalHost() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 14, 0, 0);
      return (char*)val;
    }

    inline int SetLocalHost(const char *lpLocalHost) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 14, 0, (void*)lpLocalHost, 0);
    }

    inline int GetLocalPort() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 15, 0, 0);
      return (int)(long)val;
    }
    inline int SetLocalPort(int lLocalPort) {
      void* val = (void*)IPS64CAST(lLocalPort);
      return IPWorksSSL_IPPortS_Set(m_pObj, 15, 0, val, 0);
    }
    inline char* GetRemoteHost() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 16, 0, 0);
      return (char*)val;
    }

    inline int SetRemoteHost(const char *lpRemoteHost) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 16, 0, (void*)lpRemoteHost, 0);
    }

    inline int GetRemotePort() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 17, 0, 0);
      return (int)(long)val;
    }
    inline int SetRemotePort(int lRemotePort) {
      void* val = (void*)IPS64CAST(lRemotePort);
      return IPWorksSSL_IPPortS_Set(m_pObj, 17, 0, val, 0);
    }
    inline int GetSingleLineMode() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 18, 0, 0);
      return (int)(long)val;
    }
    inline int SetSingleLineMode(int bSingleLineMode) {
      void* val = (void*)IPS64CAST(bSingleLineMode);
      return IPWorksSSL_IPPortS_Set(m_pObj, 18, 0, val, 0);
    }
    inline int GetSSLAcceptServerCertEncoded(char *&lpSSLAcceptServerCertEncoded, int &lenSSLAcceptServerCertEncoded) {
      lpSSLAcceptServerCertEncoded = (char*)IPWorksSSL_IPPortS_Get(m_pObj, 19, 0, &lenSSLAcceptServerCertEncoded);
      return lpSSLAcceptServerCertEncoded ? 0 : lenSSLAcceptServerCertEncoded;
    }

    inline int SetSSLAcceptServerCertEncoded(const char *lpSSLAcceptServerCertEncoded, int lenSSLAcceptServerCertEncoded) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 19, 0, (void*)lpSSLAcceptServerCertEncoded, lenSSLAcceptServerCertEncoded);
    }

    inline int GetSSLCertEncoded(char *&lpSSLCertEncoded, int &lenSSLCertEncoded) {
      lpSSLCertEncoded = (char*)IPWorksSSL_IPPortS_Get(m_pObj, 20, 0, &lenSSLCertEncoded);
      return lpSSLCertEncoded ? 0 : lenSSLCertEncoded;
    }

    inline int SetSSLCertEncoded(const char *lpSSLCertEncoded, int lenSSLCertEncoded) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 20, 0, (void*)lpSSLCertEncoded, lenSSLCertEncoded);
    }

    inline int GetSSLCertStore(char *&lpSSLCertStore, int &lenSSLCertStore) {
      lpSSLCertStore = (char*)IPWorksSSL_IPPortS_Get(m_pObj, 21, 0, &lenSSLCertStore);
      return lpSSLCertStore ? 0 : lenSSLCertStore;
    }

    inline int SetSSLCertStore(const char *lpSSLCertStore, int lenSSLCertStore) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 21, 0, (void*)lpSSLCertStore, lenSSLCertStore);
    }

    inline char* GetSSLCertStorePassword() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 22, 0, 0);
      return (char*)val;
    }

    inline int SetSSLCertStorePassword(const char *lpSSLCertStorePassword) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 22, 0, (void*)lpSSLCertStorePassword, 0);
    }

    inline int GetSSLCertStoreType() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 23, 0, 0);
      return (int)(long)val;
    }
    inline int SetSSLCertStoreType(int iSSLCertStoreType) {
      void* val = (void*)IPS64CAST(iSSLCertStoreType);
      return IPWorksSSL_IPPortS_Set(m_pObj, 23, 0, val, 0);
    }
    inline char* GetSSLCertSubject() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 24, 0, 0);
      return (char*)val;
    }

    inline int SetSSLCertSubject(const char *lpSSLCertSubject) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 24, 0, (void*)lpSSLCertSubject, 0);
    }

    inline int GetSSLServerCertEncoded(char *&lpSSLServerCertEncoded, int &lenSSLServerCertEncoded) {
      lpSSLServerCertEncoded = (char*)IPWorksSSL_IPPortS_Get(m_pObj, 25, 0, &lenSSLServerCertEncoded);
      return lpSSLServerCertEncoded ? 0 : lenSSLServerCertEncoded;
    }


    inline int GetSSLStartMode() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 26, 0, 0);
      return (int)(long)val;
    }
    inline int SetSSLStartMode(int iSSLStartMode) {
      void* val = (void*)IPS64CAST(iSSLStartMode);
      return IPWorksSSL_IPPortS_Set(m_pObj, 26, 0, val, 0);
    }
    inline int GetTimeout() {
      void* val = IPWorksSSL_IPPortS_Get(m_pObj, 27, 0, 0);
      return (int)(long)val;
    }
    inline int SetTimeout(int iTimeout) {
      void* val = (void*)IPS64CAST(iTimeout);
      return IPWorksSSL_IPPortS_Set(m_pObj, 27, 0, val, 0);
    }

  public: //methods

    inline char* Config(const char* lpszConfigurationString) {
      void *param[1+1] = {(void*)IPS64CAST(lpszConfigurationString), 0};
      int cbparam[1+1] = {0, 0};
      IPWorksSSL_IPPortS_Do(m_pObj, 2, 1, param, cbparam);
      
      return (char*)IPS64CAST(param[1]);
    }
    inline int Connect(const char* lpszHost, int lPort) {
      void *param[2+1] = {(void*)IPS64CAST(lpszHost), (void*)IPS64CAST(lPort), 0};
      int cbparam[2+1] = {0, 0, 0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 3, 2, param, cbparam);
      
      
    }
    inline int Disconnect() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 4, 0, param, cbparam);
      
      
    }
    inline int DoEvents() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 5, 0, param, cbparam);
      
      
    }
    inline char* GetLine() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      IPWorksSSL_IPPortS_Do(m_pObj, 6, 0, param, cbparam);
      
      return (char*)IPS64CAST(param[0]);
    }
    inline int Interrupt() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 7, 0, param, cbparam);
      
      
    }
    inline int Send(const char* lpText, int lenText) {
      void *param[1+1] = {(void*)IPS64CAST(lpText), 0};
      int cbparam[1+1] = {lenText, 0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 8, 1, param, cbparam);
      
      
    }
    inline int SendFile(const char* lpszFileName) {
      void *param[1+1] = {(void*)IPS64CAST(lpszFileName), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 9, 1, param, cbparam);
      
      
    }
    inline int SendLine(const char* lpszText) {
      void *param[1+1] = {(void*)IPS64CAST(lpszText), 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 10, 1, param, cbparam);
      
      
    }
    inline int StartSSL() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 13, 0, param, cbparam);
      
      
    }

};


#ifdef WIN32 //UNICODE

typedef struct {
  int StatusCode;
  LPWSTR Description;
  int reserved;
} IPPortSConnectedEventParamsW;

typedef struct {
  LPWSTR ConnectionEvent;
  int StatusCode;
  LPWSTR Description;
  int reserved;
} IPPortSConnectionStatusEventParamsW;

typedef struct {
  LPWSTR Text;
  int EOL;
  int lenText;
  int reserved;
} IPPortSDataInEventParamsW;

typedef struct {
  int StatusCode;
  LPWSTR Description;
  int reserved;
} IPPortSDisconnectedEventParamsW;

typedef struct {
  int ErrorCode;
  LPWSTR Description;
  int reserved;
} IPPortSErrorEventParamsW;

typedef struct {
  int reserved;
} IPPortSReadyToSendEventParamsW;

typedef struct {
  LPWSTR CertEncoded;
  LPWSTR CertSubject;
  LPWSTR CertIssuer;
  LPWSTR Status;
  int Accept;
  int lenCertEncoded;
  int reserved;
} IPPortSSSLServerAuthenticationEventParamsW;

typedef struct {
  LPWSTR Message;
  int reserved;
} IPPortSSSLStatusEventParamsW;



class IPPortSW : public IPPortS {

  public: //properties
  








    inline int SetDataToSend(LPWSTR lpDataToSend) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+4, 0, (void*)lpDataToSend, 0);
    }

    inline int SetDataToSendB(const char *lpDataToSend, int lenDataToSend) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 4, 0, (void*)lpDataToSend, lenDataToSend);
    }
    inline LPWSTR GetEOL() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+5, 0, 0);
    }

    inline int SetEOL(LPWSTR lpEOL) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+5, 0, (void*)lpEOL, 0);
    }
    inline int GetEOLB(char *&lpEOL, int &lenEOL) {
      lpEOL = (char*)IPWorksSSL_IPPortS_Get(m_pObj, 5, 0, &lenEOL);
      return lpEOL ? 0 : lenEOL;
    }
    inline int SetEOLB(const char *lpEOL, int lenEOL) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 5, 0, (void*)lpEOL, lenEOL);
    }




    inline LPWSTR GetFirewallHost() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+8, 0, 0);
    }

    inline int SetFirewallHost(LPWSTR lpFirewallHost) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+8, 0, (void*)lpFirewallHost, 0);
    }

    inline LPWSTR GetFirewallPassword() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+9, 0, 0);
    }

    inline int SetFirewallPassword(LPWSTR lpFirewallPassword) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+9, 0, (void*)lpFirewallPassword, 0);
    }



    inline LPWSTR GetFirewallUser() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+11, 0, 0);
    }

    inline int SetFirewallUser(LPWSTR lpFirewallUser) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+11, 0, (void*)lpFirewallUser, 0);
    }





    inline LPWSTR GetLocalHost() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+14, 0, 0);
    }

    inline int SetLocalHost(LPWSTR lpLocalHost) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+14, 0, (void*)lpLocalHost, 0);
    }



    inline LPWSTR GetRemoteHost() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+16, 0, 0);
    }

    inline int SetRemoteHost(LPWSTR lpRemoteHost) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+16, 0, (void*)lpRemoteHost, 0);
    }





    inline LPWSTR GetSSLAcceptServerCertEncoded() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+19, 0, 0);
    }

    inline int SetSSLAcceptServerCertEncoded(LPWSTR lpSSLAcceptServerCertEncoded) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+19, 0, (void*)lpSSLAcceptServerCertEncoded, 0);
    }
    inline int GetSSLAcceptServerCertEncodedB(char *&lpSSLAcceptServerCertEncoded, int &lenSSLAcceptServerCertEncoded) {
      lpSSLAcceptServerCertEncoded = (char*)IPWorksSSL_IPPortS_Get(m_pObj, 19, 0, &lenSSLAcceptServerCertEncoded);
      return lpSSLAcceptServerCertEncoded ? 0 : lenSSLAcceptServerCertEncoded;
    }
    inline int SetSSLAcceptServerCertEncodedB(const char *lpSSLAcceptServerCertEncoded, int lenSSLAcceptServerCertEncoded) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 19, 0, (void*)lpSSLAcceptServerCertEncoded, lenSSLAcceptServerCertEncoded);
    }
    inline LPWSTR GetSSLCertEncoded() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+20, 0, 0);
    }

    inline int SetSSLCertEncoded(LPWSTR lpSSLCertEncoded) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+20, 0, (void*)lpSSLCertEncoded, 0);
    }
    inline int GetSSLCertEncodedB(char *&lpSSLCertEncoded, int &lenSSLCertEncoded) {
      lpSSLCertEncoded = (char*)IPWorksSSL_IPPortS_Get(m_pObj, 20, 0, &lenSSLCertEncoded);
      return lpSSLCertEncoded ? 0 : lenSSLCertEncoded;
    }
    inline int SetSSLCertEncodedB(const char *lpSSLCertEncoded, int lenSSLCertEncoded) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 20, 0, (void*)lpSSLCertEncoded, lenSSLCertEncoded);
    }
    inline LPWSTR GetSSLCertStore() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+21, 0, 0);
    }

    inline int SetSSLCertStore(LPWSTR lpSSLCertStore) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+21, 0, (void*)lpSSLCertStore, 0);
    }
    inline int GetSSLCertStoreB(char *&lpSSLCertStore, int &lenSSLCertStore) {
      lpSSLCertStore = (char*)IPWorksSSL_IPPortS_Get(m_pObj, 21, 0, &lenSSLCertStore);
      return lpSSLCertStore ? 0 : lenSSLCertStore;
    }
    inline int SetSSLCertStoreB(const char *lpSSLCertStore, int lenSSLCertStore) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 21, 0, (void*)lpSSLCertStore, lenSSLCertStore);
    }
    inline LPWSTR GetSSLCertStorePassword() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+22, 0, 0);
    }

    inline int SetSSLCertStorePassword(LPWSTR lpSSLCertStorePassword) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+22, 0, (void*)lpSSLCertStorePassword, 0);
    }



    inline LPWSTR GetSSLCertSubject() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+24, 0, 0);
    }

    inline int SetSSLCertSubject(LPWSTR lpSSLCertSubject) {
      return IPWorksSSL_IPPortS_Set(m_pObj, 10000+24, 0, (void*)lpSSLCertSubject, 0);
    }

    inline LPWSTR GetSSLServerCertEncoded() {
      return (LPWSTR)IPWorksSSL_IPPortS_Get(m_pObj, 10000+25, 0, 0);
    }


    inline int GetSSLServerCertEncodedB(char *&lpSSLServerCertEncoded, int &lenSSLServerCertEncoded) {
      lpSSLServerCertEncoded = (char*)IPWorksSSL_IPPortS_Get(m_pObj, 25, 0, &lenSSLServerCertEncoded);
      return lpSSLServerCertEncoded ? 0 : lenSSLServerCertEncoded;
    }







  public: //events
  
    virtual int FireConnected(IPPortSConnectedEventParamsW *e) {return 0;}
    virtual int FireConnectionStatus(IPPortSConnectionStatusEventParamsW *e) {return 0;}
    virtual int FireDataIn(IPPortSDataInEventParamsW *e) {return 0;}
    virtual int FireDisconnected(IPPortSDisconnectedEventParamsW *e) {return 0;}
    virtual int FireError(IPPortSErrorEventParamsW *e) {return 0;}
    virtual int FireReadyToSend(IPPortSReadyToSendEventParamsW *e) {return 0;}
    virtual int FireSSLServerAuthentication(IPPortSSSLServerAuthenticationEventParamsW *e) {return 0;}
    virtual int FireSSLStatus(IPPortSSSLStatusEventParamsW *e) {return 0;}


  protected:
  
    virtual int IPPortSEventSinkW(int event_id, int cparam, void *param[], int cbparam[]) {
    	int ret_code = 0;
      switch (event_id) {
         case 1: {
            IPPortSConnectedEventParamsW e = {(int)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]),  0};
            ret_code = FireConnected(&e);
            break;
         }
         case 2: {
            IPPortSConnectionStatusEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (int)IPS64CAST(param[1]), (LPWSTR)IPS64CAST(param[2]),  0};
            ret_code = FireConnectionStatus(&e);
            break;
         }
         case 3: {
            IPPortSDataInEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (int)IPS64CAST(param[1]), (int)IPS64CAST(cbparam[0]),  0};
            ret_code = FireDataIn(&e);
            break;
         }
         case 4: {
            IPPortSDisconnectedEventParamsW e = {(int)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]),  0};
            ret_code = FireDisconnected(&e);
            break;
         }
         case 5: {
            IPPortSErrorEventParamsW e = {(int)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]),  0};
            ret_code = FireError(&e);
            break;
         }
         case 6: {
            IPPortSReadyToSendEventParamsW e = { 0};
            ret_code = FireReadyToSend(&e);
            break;
         }
         case 7: {
            IPPortSSSLServerAuthenticationEventParamsW e = {(LPWSTR)IPS64CAST(param[0]), (LPWSTR)IPS64CAST(param[1]), (LPWSTR)IPS64CAST(param[2]), (LPWSTR)IPS64CAST(param[3]), (int)IPS64CAST(param[4]), (int)IPS64CAST(cbparam[0]),  0};
            ret_code = FireSSLServerAuthentication(&e);
            param[4] = (void*)(e.Accept);
            break;
         }
         case 8: {
            IPPortSSSLStatusEventParamsW e = {(LPWSTR)IPS64CAST(param[0]),  0};
            ret_code = FireSSLStatus(&e);
            break;
         }

      }
      return ret_code;
    }
  
  public: //event overrides

    virtual int FireConnected(IPPortSConnectedEventParams *e) {return -10000;}
    virtual int FireConnectionStatus(IPPortSConnectionStatusEventParams *e) {return -10000;}
    virtual int FireDataIn(IPPortSDataInEventParams *e) {return -10000;}
    virtual int FireDisconnected(IPPortSDisconnectedEventParams *e) {return -10000;}
    virtual int FireError(IPPortSErrorEventParams *e) {return -10000;}
    virtual int FireReadyToSend(IPPortSReadyToSendEventParams *e) {return -10000;}
    virtual int FireSSLServerAuthentication(IPPortSSSLServerAuthenticationEventParams *e) {return -10000;}
    virtual int FireSSLStatus(IPPortSSSLStatusEventParams *e) {return -10000;}

  public: //methods

    inline LPWSTR Config(LPWSTR lpszConfigurationString) {
      void *param[1+1] = {(void*)lpszConfigurationString, 0};
      int cbparam[1+1] = {0, 0};
      IPWorksSSL_IPPortS_Do(m_pObj, 10000+2, 1, param, cbparam);
      return (LPWSTR)IPS64CAST(param[1]);
    }
    inline int Connect(LPWSTR lpszHost, int lPort) {
      void *param[2+1] = {(void*)lpszHost, (void*)lPort, 0};
      int cbparam[2+1] = {0, 0, 0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 10000+3, 2, param, cbparam);
      
    }
    inline int Disconnect() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 10000+4, 0, param, cbparam);
      
    }
    inline int DoEvents() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 10000+5, 0, param, cbparam);
      
    }
    inline LPWSTR GetLine() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      IPWorksSSL_IPPortS_Do(m_pObj, 10000+6, 0, param, cbparam);
      return (LPWSTR)IPS64CAST(param[0]);
    }
    inline int Interrupt() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 10000+7, 0, param, cbparam);
      
    }
    inline int Send(LPWSTR lpText, int lenText) {
      void *param[1+1] = {(void*)lpText, 0};
      int cbparam[1+1] = {lenText, 0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 10000+8, 1, param, cbparam);
      
    }
    inline int SendFile(LPWSTR lpszFileName) {
      void *param[1+1] = {(void*)lpszFileName, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 10000+9, 1, param, cbparam);
      
    }
    inline int SendLine(LPWSTR lpszText) {
      void *param[1+1] = {(void*)lpszText, 0};
      int cbparam[1+1] = {0, 0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 10000+10, 1, param, cbparam);
      
    }
    inline int StartSSL() {
      void *param[0+1] = {0};
      int cbparam[0+1] = {0};
      return IPWorksSSL_IPPortS_Do(m_pObj, 10000+13, 0, param, cbparam);
      
    }

};

#endif //WIN32

#endif //_IPWORKSSSL_IPPORTS_H_




